@@ -1,4 +1,4 @@
-/* $Id: cpl_column.h,v 1.50 2012/02/27 16:12:47 rpalsa Exp $
+/* $Id: cpl_column.h,v 1.50 2012-02-27 16:12:47 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/02/27 16:12:47 $
+ * $Date: 2012-02-27 16:12:47 $
  * $Revision: 1.50 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifndef CPL_COLUMN_H
@@ -72,8 +72,8 @@ cpl_column *cpl_column_wrap_long_long(long long *, cpl_size length);
 cpl_column *cpl_column_wrap_cplsize(cpl_size *, cpl_size length);
 cpl_column *cpl_column_wrap_float(float *, cpl_size length);
 cpl_column *cpl_column_wrap_double(double *, cpl_size length);
-cpl_column *cpl_column_wrap_float_complex(float complex *, cpl_size length);
-cpl_column *cpl_column_wrap_double_complex(double complex *, cpl_size length);
+cpl_column *cpl_column_wrap_float_complex(_Complex float *, cpl_size length);
+cpl_column *cpl_column_wrap_double_complex(_Complex double *, cpl_size length);
 cpl_column *cpl_column_wrap_string(char **, cpl_size length);
 
 void *cpl_column_unwrap(cpl_column *);
@@ -88,11 +88,11 @@ cpl_error_code cpl_column_copy_data_cplsize(cpl_column *, const cpl_size *);
 cpl_error_code cpl_column_copy_data_float(cpl_column *, const float *);
 cpl_error_code cpl_column_copy_data_double(cpl_column *, const double *);
 cpl_error_code cpl_column_copy_data_complex(cpl_column *,
-                                            const double complex *);
+                                            const _Complex double *);
 cpl_error_code cpl_column_copy_data_float_complex(cpl_column *,
-                                                  const float complex *);
+                                                  const _Complex float *);
 cpl_error_code cpl_column_copy_data_double_complex(cpl_column *,
-                                                   const double complex *);
+                                                   const _Complex double *);
 cpl_error_code cpl_column_copy_data_string(cpl_column *, const char **);
 
 void cpl_column_delete(cpl_column *);
@@ -131,11 +131,11 @@ float *cpl_column_get_data_float(cpl_column *);
 const float *cpl_column_get_data_float_const(const cpl_column *);
 double *cpl_column_get_data_double(cpl_column *);
 const double *cpl_column_get_data_double_const(const cpl_column *);
-float complex *cpl_column_get_data_float_complex(cpl_column *);
-const float complex *
+_Complex float *cpl_column_get_data_float_complex(cpl_column *);
+const _Complex float *
 cpl_column_get_data_float_complex_const(const cpl_column *);
-double complex *cpl_column_get_data_double_complex(cpl_column *);
-const double complex *
+_Complex double *cpl_column_get_data_double_complex(cpl_column *);
+const _Complex double *
 cpl_column_get_data_double_complex_const(const cpl_column *);
 char **cpl_column_get_data_string(cpl_column *);
 const char **cpl_column_get_data_string_const(const cpl_column *);
@@ -150,15 +150,15 @@ cpl_error_code cpl_column_set_size(cpl_column *, cpl_size);
 cpl_error_code cpl_column_set_depth(cpl_column *, cpl_size);
 
 double cpl_column_get(cpl_column *, cpl_size, int *null); 
-double complex cpl_column_get_complex(cpl_column *, cpl_size , int *null);
+_Complex double cpl_column_get_complex(cpl_column *, cpl_size , int *null);
 int cpl_column_get_int(cpl_column *, cpl_size, int *null); 
 long cpl_column_get_long(cpl_column *, cpl_size, int *null);
 long long cpl_column_get_long_long(cpl_column *, cpl_size, int *null);
 cpl_size cpl_column_get_cplsize(cpl_column *, cpl_size, int *null);
 float cpl_column_get_float(cpl_column *, cpl_size, int *null); 
 double cpl_column_get_double(cpl_column *, cpl_size, int *null); 
-float complex cpl_column_get_float_complex(cpl_column *, cpl_size, int *null);
-double complex cpl_column_get_double_complex(cpl_column *, cpl_size, int *null);
+_Complex float cpl_column_get_float_complex(cpl_column *, cpl_size, int *null);
+_Complex double cpl_column_get_double_complex(cpl_column *, cpl_size, int *null);
 char *cpl_column_get_string(cpl_column *, cpl_size);
 const char *cpl_column_get_string_const(const cpl_column *, cpl_size);
 cpl_array *cpl_column_get_array(cpl_column *, cpl_size);
@@ -171,9 +171,9 @@ cpl_error_code cpl_column_set_long_long(cpl_column *, cpl_size, long long);
 cpl_error_code cpl_column_set_cplsize(cpl_column *, cpl_size, cpl_size);
 cpl_error_code cpl_column_set_float(cpl_column *, cpl_size, float); 
 cpl_error_code cpl_column_set_double(cpl_column *, cpl_size, double); 
-cpl_error_code cpl_column_set_complex(cpl_column *, cpl_size, double complex);
-cpl_error_code cpl_column_set_float_complex(cpl_column *, cpl_size, float complex);
-cpl_error_code cpl_column_set_double_complex(cpl_column *, cpl_size, double complex);
+cpl_error_code cpl_column_set_complex(cpl_column *, cpl_size, _Complex double);
+cpl_error_code cpl_column_set_float_complex(cpl_column *, cpl_size, _Complex float);
+cpl_error_code cpl_column_set_double_complex(cpl_column *, cpl_size, _Complex double);
 cpl_error_code cpl_column_set_string(cpl_column *, cpl_size, const char *);
 cpl_error_code cpl_column_set_array(cpl_column *, cpl_size, const cpl_array *);
 
@@ -184,11 +184,11 @@ cpl_error_code cpl_column_fill_long_long(cpl_column *, cpl_size, cpl_size, long
 cpl_error_code cpl_column_fill_cplsize(cpl_column *, cpl_size, cpl_size, cpl_size);
 cpl_error_code cpl_column_fill_float(cpl_column *, cpl_size, cpl_size, float); 
 cpl_error_code cpl_column_fill_double(cpl_column *, cpl_size, cpl_size, double);
-cpl_error_code cpl_column_fill_complex(cpl_column *, cpl_size, cpl_size, double complex);
+cpl_error_code cpl_column_fill_complex(cpl_column *, cpl_size, cpl_size, _Complex double);
 cpl_error_code cpl_column_fill_float_complex(cpl_column *, 
-                                             cpl_size, cpl_size, float complex);
+                                             cpl_size, cpl_size, _Complex float);
 cpl_error_code cpl_column_fill_double_complex(cpl_column *, 
-                                              cpl_size, cpl_size, double complex);
+                                              cpl_size, cpl_size, _Complex double);
 cpl_error_code cpl_column_fill_string(cpl_column *, cpl_size, cpl_size, const char *);
 cpl_error_code cpl_column_fill_array(cpl_column *, cpl_size, cpl_size, const cpl_array *);
 
@@ -202,11 +202,11 @@ cpl_error_code cpl_column_copy_segment_cplsize(cpl_column *, cpl_size,
 cpl_error_code cpl_column_copy_segment_float(cpl_column *, cpl_size, cpl_size, float *);
 cpl_error_code cpl_column_copy_segment_double(cpl_column *, cpl_size, cpl_size, double *);
 cpl_error_code cpl_column_copy_segment_complex(cpl_column *, 
-                                               cpl_size, cpl_size, double complex *);
+                                               cpl_size, cpl_size, _Complex double *);
 cpl_error_code cpl_column_copy_segment_float_complex(cpl_column *, 
-                                               cpl_size, cpl_size, float complex *);
+                                               cpl_size, cpl_size, _Complex float *);
 cpl_error_code cpl_column_copy_segment_double_complex(cpl_column *, 
-                                               cpl_size, cpl_size, double complex *);
+                                               cpl_size, cpl_size, _Complex double *);
 cpl_error_code cpl_column_copy_segment_string(cpl_column *, cpl_size, cpl_size, char **);
 cpl_error_code cpl_column_copy_segment_array(cpl_column *, cpl_size, cpl_size, 
                                              cpl_array **);
@@ -227,9 +227,9 @@ cpl_error_code cpl_column_fill_invalid_cplsize(cpl_column *, cpl_size);
 cpl_error_code cpl_column_fill_invalid_float(cpl_column *, float);
 cpl_error_code cpl_column_fill_invalid_double(cpl_column *, double);
 cpl_error_code cpl_column_fill_invalid_float_complex(cpl_column *, 
-                                                     float complex);
+                                                     _Complex float);
 cpl_error_code cpl_column_fill_invalid_double_complex(cpl_column *, 
-                                                     double complex);
+                                                     _Complex double);
 
 cpl_error_code cpl_column_erase_segment(cpl_column *, cpl_size, cpl_size);
 cpl_error_code cpl_column_erase_pattern(cpl_column *, int *);
@@ -272,13 +272,13 @@ cpl_error_code cpl_column_multiply(cpl_column *, cpl_column *);
 cpl_error_code cpl_column_divide(cpl_column *, cpl_column *);
 
 cpl_error_code cpl_column_add_scalar(cpl_column *, double);
-cpl_error_code cpl_column_add_scalar_complex(cpl_column *, double complex);
+cpl_error_code cpl_column_add_scalar_complex(cpl_column *, _Complex double);
 cpl_error_code cpl_column_subtract_scalar(cpl_column *, double);
-cpl_error_code cpl_column_subtract_scalar_complex(cpl_column *, double complex);
+cpl_error_code cpl_column_subtract_scalar_complex(cpl_column *, _Complex double);
 cpl_error_code cpl_column_multiply_scalar(cpl_column *, double);
-cpl_error_code cpl_column_multiply_scalar_complex(cpl_column *, double complex);
+cpl_error_code cpl_column_multiply_scalar_complex(cpl_column *, _Complex double);
 cpl_error_code cpl_column_divide_scalar(cpl_column *, double);
-cpl_error_code cpl_column_divide_scalar_complex(cpl_column *, double complex);
+cpl_error_code cpl_column_divide_scalar_complex(cpl_column *, _Complex double);
 cpl_error_code cpl_column_absolute(cpl_column *);
 cpl_column *cpl_column_absolute_complex(cpl_column *);
 cpl_column *cpl_column_phase_complex(cpl_column *);
@@ -290,7 +290,7 @@ cpl_error_code cpl_column_exponential(cpl_column *, double);
 cpl_error_code cpl_column_conjugate(cpl_column *);
 
 double cpl_column_get_mean(cpl_column *);
-double complex cpl_column_get_mean_complex(cpl_column *);
+_Complex double cpl_column_get_mean_complex(cpl_column *);
 double cpl_column_get_median(cpl_column *);
 double cpl_column_get_stdev(cpl_column *);
 
