@@ -1,4 +1,4 @@
-/* $Id: cpl_error.h,v 1.81.2.1 2013/05/02 09:39:31 llundin Exp $
+/* $Id: cpl_error.h,v 1.83 2013-10-14 11:21:00 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2013/05/02 09:39:31 $
- * $Revision: 1.81.2.1 $
- * $Name: cpl-6_3_1 $
+ * $Date: 2013-10-14 11:21:00 $
+ * $Revision: 1.83 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifndef CPL_ERROR_H
@@ -179,7 +179,7 @@ CPL_BEGIN_DECLS
 
 #if defined CPL_HAVE_VA_ARGS && CPL_HAVE_VA_ARGS == 1 || defined DOXYGEN_SKIP
 #define cpl_error_ensure(CONDITION, CODE, ACTION, ...)                         \
-    do if (!(CONDITION)) {                                                     \
+    do if (CPL_UNLIKELY(!(CONDITION))) {                                       \
         /* Evaluate exactly once using a name-space protected variable name */ \
         const cpl_error_code cpl_ensure_error = (CODE);                        \
         (void)cpl_error_set_message_macro(cpl_func, cpl_ensure_error           \
@@ -190,7 +190,7 @@ CPL_BEGIN_DECLS
     } while (0)
 #else
 #define cpl_error_ensure(CONDITION, CODE, ACTION, MSG)                         \
-    do if (!(CONDITION)) {                                                     \
+    do if (CPL_UNLIKELY(!(CONDITION))) {                                       \
         /* Evaluate exactly once using a name-space protected variable name */ \
         const cpl_error_code cpl_ensure_error = (CODE);                        \
         (void)cpl_error_set_message_one_macro(cpl_func, cpl_ensure_error       \
