@@ -58,11 +58,52 @@ static cpl_error_code CPL_CONCAT2X(cpl_image_hypot, CPL_CONCAT2X(CPL_TYPE1,
     if (first == NULL) {
         for (i = 0; i < nxy; i++)
             p1[i] = (CPL_TYPE1)CPL_HYPOT(p1[i], p3[i]);
+
+        /* Handle bad pixels map */
+        if (second->bpm != NULL) {
+            if (self->bpm == NULL) {
+                self->bpm = cpl_mask_duplicate(second->bpm);
+            } else {
+                cpl_mask_or(self->bpm, second->bpm);
+            }
+        }
     } else {
         const CPL_TYPE2 * p2  = (const CPL_TYPE2 *)first->pixels;
 
         for (i = 0; i < nxy; i++)
             p1[i] = (CPL_TYPE1)CPL_HYPOT(p2[i], p3[i]);
+
+        /* Handle bad pixels map */
+        if (first->bpm != NULL && second->bpm != NULL) {
+            if (self->bpm == NULL) self->bpm =
+                cpl_mask_wrap(self->nx, self->ny, (cpl_binary*)cpl_malloc(nxy));
+
+            cpl_mask_or_(cpl_mask_get_data(self->bpm),
+                         cpl_mask_get_data_const(first->bpm),
+                         cpl_mask_get_data_const(second->bpm), nxy);
+        } else if (first->bpm != NULL) {
+            assert( second->bpm == NULL );
+            if (self->bpm == NULL) {
+                self->bpm = cpl_mask_duplicate(first->bpm);
+            } else {
+                (void)memcpy(cpl_mask_get_data(self->bpm),
+                             cpl_mask_get_data_const(first->bpm), nxy);
+            }
+        } else if (second->bpm != NULL) {
+            assert( first-> bpm == NULL );
+            if (self->bpm == NULL) {
+                self->bpm = cpl_mask_duplicate(second->bpm);
+            } else {
+                (void)memcpy(cpl_mask_get_data(self->bpm),
+                             cpl_mask_get_data_const(second->bpm), nxy);
+            }
+        } else if (self->bpm != NULL) {
+            /* The input has no bad pixel map. We already have an output
+               bpm and we don't know where it comes from, so instead of
+               deallocating it, we just clear it. If the caller does not
+               want a bad pixel map it should be deallocated by the caller */
+            (void)memset(cpl_mask_get_data(self->bpm), 0, nxy);
+        }
     }
 
     return CPL_ERROR_NONE;
