@@ -1015,8 +1015,9 @@ ADDTYPE_TWO(cpl_filter_stdev)(void * vout,
 /*----------------------------------------------------------------------------*/
 static void
 ADDTYPE_TWO(cpl_filter_average)(void * vout, const void * vin,
-                                 cpl_size nx, cpl_size ny, cpl_size hsizex, cpl_size hsizey,
-                                 cpl_border_mode border_mode)
+                                cpl_size nx, cpl_size ny,
+                                cpl_size hsizex, cpl_size hsizey,
+                                cpl_border_mode border_mode)
 {
 
     OUT_TYPE * out = (OUT_TYPE*)vout;
@@ -1276,7 +1277,8 @@ ADDTYPE_TWO(cpl_filter_average)(void * vout, const void * vin,
 static void
 ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
                                     const void * vin, const cpl_binary * bpm,
-                                    cpl_size nx, cpl_size ny, cpl_size hsizex, cpl_size hsizey,
+                                    cpl_size nx, cpl_size ny,
+                                    cpl_size hsizex, cpl_size hsizey,
                                     cpl_border_mode border_mode)
 {
 
@@ -1341,7 +1343,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
@@ -1365,7 +1368,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
@@ -1398,7 +1402,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
@@ -1416,7 +1421,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
@@ -1454,7 +1460,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
@@ -1481,7 +1488,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
@@ -1520,7 +1528,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
@@ -1537,7 +1546,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
@@ -1572,7 +1582,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
@@ -1595,7 +1606,8 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
             } else {
                 /* Flag as bad - and set to zero */
                 if (*pbpm == NULL) *pbpm
-                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny, sizeof(cpl_binary));
+                    = (cpl_binary*)cpl_calloc((size_t)nx * (size_t)ny,
+                                              sizeof(cpl_binary));
                 (*pbpm)[x + y * nx] = CPL_BINARY_1;
                 out[x + y * nx] = (OUT_TYPE)0;
             }
