@@ -167,7 +167,13 @@
 
     /* Test entries */
     cpl_ensure(img, CPL_ERROR_NULL_INPUT, NULL);
-    cpl_ensure(img->type == CPL_TYPE_T, CPL_ERROR_TYPE_MISMATCH, NULL);
+    if (img->type != CPL_TYPE_T) {
+        (void)cpl_error_set_message_(CPL_ERROR_TYPE_MISMATCH,
+                                     "Expected pixel type %s, not %s",
+                                     cpl_type_get_name(CPL_TYPE_T),
+                                     cpl_type_get_name(img->type));
+        return NULL;
+    }
 
     return (CPL_CONST CPL_TYPE*)img->pixels;
 
