@@ -966,8 +966,8 @@ double     *pchi
 
     result.xerror = cpl_malloc(MA * sizeof(result.xerror[0]));
 
-    status = mpfit((mp_func)&g2efunc2, nx * ny, MA,
-                   a, pars, NULL, NULL, &result);
+    status = cpl_mpfit((mp_func)&g2efunc2, nx * ny, MA, a, pars,
+                       NULL, NULL, &result);
 
 
     for (i = 0; i < MA; i++) {
