@@ -519,6 +519,25 @@ cpl_error_code cpl_imagelist_threshold(
     return CPL_ERROR_NONE;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @ingroup cpl_imagelist
+  @internal
+  @brief    subtract one from an integer image where the mask is true
+  @param    img  output integer image
+  @param    mask input mask
+ */
+/*----------------------------------------------------------------------------*/
+static void mask_sub(cpl_image * img, const cpl_mask * mask)
+{
+    size_t npix = cpl_image_get_size_x(img) * cpl_image_get_size_y(img);
+    int * imgd = cpl_image_get_data_int(img);
+    const cpl_binary * maskd = cpl_mask_get_data_const(mask);
+    for (size_t i = 0; i < npix; i++) {
+        imgd[i] -= maskd[i] != CPL_BINARY_0;
+    }
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @ingroup cpl_imagelist
@@ -540,9 +559,9 @@ cpl_image * cpl_image_new_from_accepted(const cpl_imagelist * imlist)
     const cpl_image * first = cpl_imagelist_get_const(imlist, 0);
     const cpl_size    nx    = cpl_image_get_size_x(first);
     const cpl_size    ny    = cpl_image_get_size_y(first);
-    const cpl_size    nz    = cpl_imagelist_get_size(imlist);
+    const size_t      nz    = cpl_imagelist_get_size(imlist);
     cpl_image       * goodsum;
-    cpl_size          i;
+    size_t            i;
     
 
     cpl_ensure(imlist != NULL, CPL_ERROR_NULL_INPUT, NULL);
@@ -552,19 +571,14 @@ cpl_image * cpl_image_new_from_accepted(const cpl_imagelist * imlist)
     goodsum = cpl_image_new(nx, ny, CPL_TYPE_INT);
     (void)cpl_image_add_scalar(goodsum, (double)nz); /* Assume all good */
 
+
     /* Loop on the images */
     for (i = 0; i < nz; i++) {
         const cpl_mask * bpmap
             = cpl_image_get_bpm_const(cpl_imagelist_get_const(imlist, i));
 
         if (bpmap != NULL) {
-            /* Bad pixels get value 1, good ones 0 */
-            cpl_image * badone = cpl_image_new_from_mask(bpmap);
-
-            (void)cpl_image_subtract(goodsum, badone);
-
-            /* FIXME: Reuse badone */
-            cpl_image_delete(badone);
+            mask_sub(goodsum, bpmap);
         }
     }
 
