@@ -93,17 +93,6 @@
     return CPL_ERROR_NONE;
 
 #elif CPL_OPERATION == CPL_IMLIST_BASIC_TIME_MEDIAN
-#ifndef L2_CACHE_BYTES
-#ifdef CPL_CPU_CACHE
-#define L2_CACHE_BYTES CPL_CPU_CACHE
-#else
-/* The size in bytes of the cache level, with most importance 
-   (probably related to size times penalty for a miss) */
-/* FIXME: Assume 256kB (L2) Cache. Many CPUs have more (e.g. 512kB),
-          but the performance on those does not seem to suffer much */
-#define L2_CACHE_BYTES 262144
-#endif
-#endif
     case CPL_TYPE_T:
     {
         const size_t        nz = self->ni;
@@ -133,110 +122,59 @@
             }
         }
 
-
-#if L2_CACHE_BYTES > 0
-        if (L2_CACHE_BYTES > 0 &&
-            sizeof(CPL_TYPE) * nz * (1 + nx * ny) > L2_CACHE_BYTES) {
-            /* There is a cache available, and the entire imagelist does not
-               fit inside it */
-
-            /* Heuristics: When there are just a few planes, remapping does not
-               pay off. It seems that break-even is at nz = nx / 15. */
-            const size_t max_aspect = 15;
-
-            /* The largest number of pixels that can be handled by the cache */
-            const size_t mxl2 = (L2_CACHE_BYTES - sizeof(CPL_TYPE *) * nz)
-                / (sizeof(CPL_TYPE) * (1 + 2 * nz));
-            const size_t mxmax = mxl2 < nz * max_aspect
-                ? mxl2 : nz * max_aspect;
-            size_t mx = nx;
-            size_t my = ny;
-
-
-            while ((mx & 1) == 0 && mx > mxmax) {
-                /* Make mx smaller, until it fits */
-                mx >>= 1;
-                my <<= 1;
-            }
-
-            if (mx == nx ) {
-                /* Did not yet change mx, try to make it larger while it fits */
-                while ((mx<<1) < mxmax && (my & 1) == 0) {
-                    mx <<=1;
-                    my >>=1;
-                }
-            }
-
-
-            if (sizeof(CPL_TYPE *) * (size_t)nz + sizeof(CPL_TYPE)
-                * (size_t)mx * (size_t)(1 + 2 * nz) > L2_CACHE_BYTES/2) {
-                /* Heuristics: Too few planes may cause only a fraction of the
-                   cache to be usable, in this case fall back on the simple
-                   method. It seems that the break-even is about 50% cache
-                   usage */
-
-                size_t * ngood = cpl_calloc((size_t)mx, sizeof(*ngood));
-                timeline = cpl_malloc((size_t)mx * (size_t)nz
-                                      * sizeof(CPL_TYPE));
-
-                /* For each time line */
-                for (j=0; j < my; j++) {
-                    /* Get the pixels on the current time line  */
-                    if (pbpm == NULL) {
-                        for (k=0; k < nz; k++) {
-                            for (i=0; i < mx; i++) {
-                                timeline[k + i * nz] = pi[k][i + j * mx];
-                            }
-                        }
-                        for (i=0; i < mx; i++) {
-                            /* Compute the median */
-                            po[i + j * mx] = CPL_IMAGE_GET_MEDIAN
-                                (timeline + i * nz, nz);
-                        }
-                    } else {
-                        for (k=0; k < nz; k++) {
-                            for (i=0; i < mx; i++) {
-                                if (pbpm[k] == NULL || !pbpm[k][i + j * mx]) {
-                                    timeline[ngood[i]++ + i * nz] =
-                                        pi[k][i + j * mx];
-                                }
-                            }
-                        }
-                        for (i=0; i < mx; i++) {
-                            if (ngood[i] > 0) {
-                                /* Compute the median */
-                                po[i + j * mx] = CPL_IMAGE_GET_MEDIAN
-                                    (timeline + i * nz, ngood[i]);
-                                ngood[i] = 0;
-                            } else {
-                                po[i + j * mx] = (CPL_TYPE)0;
-                                cpl_image_reject(median,
-                                                 (i + j * mx) % nx + 1,
-                                                 (i + j * mx) / nx + 1);
-                            }
-                        }
-                    }
-                }
-                cpl_free(ngood);
-            }
-        }
-#endif
-        if (timeline == NULL)  {
-            /* Remap one pixel at a time */
-            timeline = cpl_malloc((size_t)nz * sizeof(CPL_TYPE));
+        {
+            const size_t cacheline = 64 / sizeof(CPL_TYPE);
+            timeline = cpl_malloc((size_t)nz * sizeof(CPL_TYPE) * cacheline);
             if (pbpm == NULL) {
                 /* For each time line */
-                for (i=0; i < nx * ny; i++) {
+                for (i=0; i < nx * ny - ((nx * ny) % cacheline); i+=cacheline) {
                     /* Get the pixels on the current time line  */
-                    for (k=0; k < nz; k++)
+                    for (k=0; k < nz; k++) {
+                        for (j = 0; j < cacheline; j++) {
+                            CPL_TYPE * pik = pi[k];
+                            timeline[k + j * nz] = pik[i + j];
+                        }
+                    }
+
+                    /* Compute the median */
+                    for (j = 0; j < cacheline; j++) {
+                        po[i + j] = CPL_IMAGE_GET_MEDIAN(timeline + j * nz, nz);
+                    }
+                }
+                for (; i < nx * ny; i++) {
+                    /* Get the pixels on the current time line  */
+                    for (k=0; k < nz; k++) {
                         timeline[k] = pi[k][i];
+                    }
 
                     /* Compute the median */
                     po[i] = CPL_IMAGE_GET_MEDIAN(timeline, nz);
                 }
             } else {
                 /* For each time line */
-                for (i=0; i < nx * ny; i++) {
+                for (i=0; i < nx * ny - ((nx * ny) % cacheline); i+=cacheline) {
+                    /* Get the pixels on the current time line  */
+                    size_t igood[cacheline];
+                    memset(igood, 0, sizeof(igood));
+                    for (k=0; k < nz; k++) {
+                        for (j = 0; j < cacheline; j++) {
+                            if (pbpm[k] == NULL || !pbpm[k][i + j]) {
+                                timeline[j * nz + igood[j]++] = pi[k][i + j];
+                            }
+                        }
+                    }
+
+                    for (j = 0; j < cacheline; j++) {
+                        if (igood[j] > 0) {
+                            /* Compute the median */
+                            po[i + j] = CPL_IMAGE_GET_MEDIAN(timeline + j * nz, igood[j]);
+                        } else {
+                            po[i + j] = (CPL_TYPE)0;
+                            cpl_image_reject(median, (i + j)%nx + 1, (i + j)/nx + 1);
+                        }
+                    }
+                }
+                for (; i < nx * ny; i++) {
                     /* Get the pixels on the current time line  */
                     size_t igood = 0;
                     for (k=0; k < nz; k++) {
