@@ -1,4 +1,4 @@
-/* $Id: cpl_imagelist_io.c,v 1.108 2013/02/22 14:29:33 llundin Exp $
+/* $Id: cpl_imagelist_io.c,v 1.109 2013-04-12 07:49:36 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2013/02/22 14:29:33 $
- * $Revision: 1.108 $
- * $Name: cpl-6_3_1 $
+ * $Date: 2013-04-12 07:49:36 $
+ * $Revision: 1.109 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -686,7 +686,7 @@ cpl_error_code cpl_imagelist_save(const cpl_imagelist    * self,
     cpl_ensure_code(cpl_imagelist_is_uniform(self)==0,
                     CPL_ERROR_ILLEGAL_INPUT);
 
-    return cpl_image_save_((const cpl_image**)(self->images), self->ni,
+    return cpl_image_save_((const cpl_image* const*)self->images, self->ni,
                            CPL_TRUE, filename, type, pl, mode)
         ? cpl_error_set_where_() : CPL_ERROR_NONE;
 }
