@@ -1,4 +1,4 @@
-/* $Id: cpl_init.c,v 1.47 2012/05/02 10:13:19 llundin Exp $
+/* $Id: cpl_init.c,v 1.48 2013-04-26 13:43:04 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/05/02 10:13:19 $
- * $Revision: 1.47 $
- * $Name: cpl-6_3_1 $
+ * $Date: 2013-04-26 13:43:04 $
+ * $Revision: 1.48 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -209,7 +209,7 @@ cpl_init(unsigned self)
             cpl_msg_warning(cpl_func, "%s. Continue at your own risk.",
                             err_msg);
         }
-        cpl_free((char*)err_msg);
+        cpl_free(err_msg);
         err_msg = NULL;
     }
 
