@@ -285,7 +285,7 @@ CPL_BEGIN_DECLS
  */
 /*----------------------------------------------------------------------------*/
 #define CPL_MIN(first, second)                                          \
-    ((first) < (second) ? (first) : (second)) /* Two evaluations of minimum */
+  (((first) < (second)) ? (first) : (second)) /* Two evaluations of minimum */
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -299,7 +299,7 @@ CPL_BEGIN_DECLS
  */
 /*----------------------------------------------------------------------------*/
 #define CPL_MAX(first, second)                  \
-    ((first) > (second) ? (first) : (second)) /* Two evaluations of maximum */
+  (((first) > (second)) ? (first) : (second)) /* Two evaluations of maximum */
 
 /**@}*/
 
