@@ -1,4 +1,4 @@
-/* $Id: cpl_matrix_impl.h,v 1.7 2011/02/10 13:59:03 llundin Exp $
+/* $Id: cpl_matrix_impl.h,v 1.8 2013-09-05 11:23:11 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2011/02/10 13:59:03 $
- * $Revision: 1.7 $
- * $Name: cpl-6_3_1 $
+ * $Date: 2013-09-05 11:23:11 $
+ * $Revision: 1.8 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifndef CPL_MATRIX_IMPL_H
@@ -32,6 +32,9 @@
  
 CPL_BEGIN_DECLS
 
+cpl_error_code cpl_matrix_product_normal(cpl_matrix *,
+                                         const cpl_matrix *);
+
 cpl_matrix * cpl_matrix_product_normal_create(const cpl_matrix *)
     CPL_ATTR_ALLOC;
 
