@@ -1085,7 +1085,7 @@ int _cpl_mp_fdjac2(mp_func funct,
   ij = 0;
   ldfjac = 0; /* Prevents compiler warning */
 
-  dvec = (double **) cpl_calloc(npar, sizeof(double **));
+  dvec = (double **) cpl_calloc(npar, sizeof(double *));
   if (dvec == 0) return MP_ERR_MEMORY;
 
   /* Initialize the Jacobian derivative matrix */
