@@ -271,10 +271,13 @@ static void getTimeISO8601(char * timeISO8601)
 {
 
     const time_t seconds = time((time_t *)NULL);
-
-    if (strftime(timeISO8601, TIME_ISO8601_LENGTH,
-                    "%Y-%m-%dT%T", localtime(&seconds)) == 0)
+    int errnopre = errno;
+    size_t result = strftime(timeISO8601, TIME_ISO8601_LENGTH,
+                             "%Y-%m-%dT%T", localtime(&seconds));
+    errno = errnopre;  /* Preserve original errno across strftime call. */
+    if (result == 0) {
         strcpy(timeISO8601, "0000-00-00T00:00:00");
+    }
 
 }
 
