@@ -1,4 +1,4 @@
-/* $Id: cpl_plot.c,v 1.22 2012/05/21 12:40:05 llundin Exp $
+/* $Id: cpl_plot.c,v 1.22 2012-05-21 12:40:05 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/05/21 12:40:05 $
+ * $Date: 2012-05-21 12:40:05 $
  * $Revision: 1.22 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -333,7 +333,7 @@ cpl_error_code cpl_plot_vectors(const char          *   pre,
         /* Open temporary file for output   */
     if ((tmpfd=fopen(names[i-1], "w"))==NULL) {
             cpl_mplot_close(plot, post);
-            for (i=1; i<nvec; i++) remove(names[i-1]); 
+            for (i=1; i<nvec; i++) (void) remove(names[i-1]);
             for (i=1; i<nvec; i++) cpl_free(names[i-1]); 
             cpl_free(names); 
             return CPL_ERROR_FILE_IO;
@@ -366,7 +366,7 @@ cpl_error_code cpl_plot_vectors(const char          *   pre,
         cpl_free(sval);
     }
     cpl_mplot_close(plot, post);
-    for (i=1; i<nvec; i++) remove(names[i-1]); 
+    for (i=1; i<nvec; i++) (void) remove(names[i-1]);
     for (i=1; i<nvec; i++) cpl_free(names[i-1]); 
     cpl_free(names); 
 
@@ -449,7 +449,7 @@ cpl_error_code cpl_plot_bivectors(const char         *  pre,
         /* Open temporary file for output */
         if ((tmpfd=fopen(names[i], "w"))==NULL) {
             cpl_mplot_close(plot, post);
-            for (i=0; i<nbvec; i++) remove(names[i]);
+            for (i=0; i<nbvec; i++) (void) remove(names[i]);
             for (i=0; i<nbvec; i++) cpl_free(names[i]);
             cpl_free(names);
             return CPL_ERROR_FILE_IO;
@@ -474,7 +474,7 @@ cpl_error_code cpl_plot_bivectors(const char         *  pre,
         cpl_free(sval);
     }
     cpl_mplot_close(plot, post);
-    for (i=0; i<nbvec; i++) remove(names[i]);
+    for (i=0; i<nbvec; i++) (void) remove(names[i]);
     for (i=0; i<nbvec; i++) cpl_free(names[i]);
     cpl_free(names);
 
@@ -1088,8 +1088,12 @@ cpl_error_code cpl_plot_column(
     else
     {
         tempy = NULL;
-        yvec = cpl_vector_wrap(n, cpl_table_get_data_double((cpl_table*)tab,
-                                                                ylab));
+CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
+        yvec = cpl_vector_wrap(n,
+                               (double*)cpl_table_get_data_double_const(tab,
+                                                                        ylab));
+CPL_DIAG_PRAGMA_POP;
+
     }
      /* Cast columns to CPL_TYPE_DOUBLE and remove invalid entries */
     if (type_x != CPL_TYPE_DOUBLE || invalid_x > 0) {
@@ -1118,8 +1122,10 @@ cpl_error_code cpl_plot_column(
                 cpl_vector_set(xvec, i, (double)i+1);
             }
         } else {
-            xvec = cpl_vector_wrap(n, cpl_table_get_data_double((cpl_table*)tab,
-                                                                    xlab));
+CPL_DIAG_PRAGMA_PUSH_IGN(-Wcast-qual);
+            xvec = cpl_vector_wrap(n,(double*)
+                                   cpl_table_get_data_double_const(tab, xlab));
+CPL_DIAG_PRAGMA_POP;
         }
     }
    
@@ -1235,7 +1241,7 @@ cpl_error_code cpl_plot_columns(const char      *  pre,
             cpl_table_delete(tempx);
             cpl_table_delete(tempy);
             cpl_mplot_close(plot, post);
-            for (j=1; j<nlabels; j++) remove(names[j-1]);
+            for (j=1; j<nlabels; j++) (void) remove(names[j-1]);
             for (j=1; j<nlabels; j++) cpl_free(names[j-1]);
             cpl_free(names);
             return cpl_error_set_(CPL_ERROR_INVALID_TYPE);
@@ -1258,7 +1264,7 @@ cpl_error_code cpl_plot_columns(const char      *  pre,
             cpl_table_delete(tempx);
             cpl_table_delete(tempy);
             cpl_mplot_close(plot, post);
-            for (j=1; j<nlabels; j++) remove(names[j-1]);
+            for (j=1; j<nlabels; j++) (void) remove(names[j-1]);
             for (j=1; j<nlabels; j++) cpl_free(names[j-1]);
             cpl_free(names);
             return cpl_error_set_(CPL_ERROR_FILE_IO);
@@ -1290,7 +1296,7 @@ cpl_error_code cpl_plot_columns(const char      *  pre,
         cpl_free(sval);
     }
     cpl_mplot_close(plot, post);
-    for (i=1; i<nlabels; i++) remove(names[i-1]);
+    for (i=1; i<nlabels; i++) (void) remove(names[i-1]);
     for (i=1; i<nlabels; i++) cpl_free(names[i-1]);
     cpl_free(names);
     cpl_table_delete(tempx);
@@ -1387,7 +1393,6 @@ static cpl_plot * cpl_mplot_open(const char * options)
 
 
     cpl_ensure(exe != NULL, CPL_ERROR_NULL_INPUT, NULL);
-    cpl_ensure(tmp != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
     cpl_error_ensure(strstr(exe, "gnuplot"), CPL_ERROR_UNSUPPORTED_MODE,
                      return NULL, "%s", exe);
@@ -1449,7 +1454,6 @@ static cpl_plot * cpl_image_open(const char * options)
 
 
     cpl_ensure(exe != NULL, CPL_ERROR_NULL_INPUT, NULL);
-    cpl_ensure(tmp != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
     data = fopen(tmp, "w");
 
@@ -1513,7 +1517,7 @@ static cpl_error_code cpl_mplot_close(cpl_plot * plot,
                                    "%d", command ? command : "<NULL>", nstat);
         cpl_free(command);
     }
-    remove(plot->tmp);
+    (void) remove(plot->tmp);
 
     cpl_free(plot);
 
