@@ -1,4 +1,4 @@
-/* $Id: cpl_table.h,v 1.68 2013/01/23 16:06:32 rpalsa Exp $
+/* $Id: cpl_table.h,v 1.68 2013-01-23 16:06:32 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2013/01/23 16:06:32 $
+ * $Date: 2013-01-23 16:06:32 $
  * $Revision: 1.68 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 
@@ -74,9 +74,9 @@ cpl_error_code cpl_table_wrap_float(cpl_table *, float *, const char *);
 cpl_error_code cpl_table_wrap_double(cpl_table *, double *, const char *);
 #ifdef _Complex_I
 cpl_error_code cpl_table_wrap_float_complex(cpl_table *, 
-                                            float complex *, const char *);
+                                            _Complex float *, const char *);
 cpl_error_code cpl_table_wrap_double_complex(cpl_table *, 
-                                             double complex *, const char *);
+                                             _Complex double *, const char *);
 #endif
 cpl_error_code cpl_table_wrap_string(cpl_table *, char **, const char *);
 
@@ -125,11 +125,11 @@ double *cpl_table_get_data_double(cpl_table *, const char *name);
 const double *cpl_table_get_data_double_const(const cpl_table *, 
                                               const char *name);
 #ifdef _Complex_I
-float complex *cpl_table_get_data_float_complex(cpl_table *, const char *name);
-const float complex *cpl_table_get_data_float_complex_const(const cpl_table *, 
+_Complex float *cpl_table_get_data_float_complex(cpl_table *, const char *name);
+const _Complex float *cpl_table_get_data_float_complex_const(const cpl_table *, 
                                                             const char *name);
-double complex *cpl_table_get_data_double_complex(cpl_table *, const char *);
-const double complex *cpl_table_get_data_double_complex_const(const cpl_table *,
+_Complex double *cpl_table_get_data_double_complex(cpl_table *, const char *);
+const _Complex double *cpl_table_get_data_double_complex_const(const cpl_table *,
                                                               const char *);
 #endif
 char **cpl_table_get_data_string(cpl_table *, const char *name);
@@ -147,11 +147,11 @@ float cpl_table_get_float(const cpl_table *, const char *, cpl_size, int *null);
 double cpl_table_get_double(const cpl_table *, const char *, cpl_size, 
                                                                 int *null);
 #ifdef _Complex_I
-double complex cpl_table_get_complex(const cpl_table *,
+_Complex double cpl_table_get_complex(const cpl_table *,
                                      const char *, cpl_size, int *);
-float complex cpl_table_get_float_complex(const cpl_table *, 
+_Complex float cpl_table_get_float_complex(const cpl_table *, 
                                           const char *, cpl_size, int *null);
-double complex cpl_table_get_double_complex(const cpl_table *, 
+_Complex double cpl_table_get_double_complex(const cpl_table *, 
                                           const char *, cpl_size, int *null);
 #endif
 const char *cpl_table_get_string(const cpl_table *, const char *, cpl_size);
@@ -166,11 +166,11 @@ cpl_error_code cpl_table_set_double(cpl_table *, const char *, cpl_size,
                                                                     double);
 #ifdef _Complex_I
 cpl_error_code cpl_table_set_complex(cpl_table *, 
-                                     const char *, cpl_size, double complex);
+                                     const char *, cpl_size, _Complex double);
 cpl_error_code cpl_table_set_float_complex(cpl_table *, 
-                                     const char *, cpl_size, float complex);
+                                     const char *, cpl_size, _Complex float);
 cpl_error_code cpl_table_set_double_complex(cpl_table *, 
-                                     const char *, cpl_size, double complex);
+                                     const char *, cpl_size, _Complex double);
 #endif
 cpl_error_code cpl_table_set_string(cpl_table *, const char *, cpl_size, 
                                     const char *);
@@ -190,11 +190,11 @@ cpl_error_code cpl_table_fill_column_window_double(cpl_table *, const char *,
                                             cpl_size, cpl_size, double);
 #ifdef _Complex_I
 cpl_error_code cpl_table_fill_column_window_complex(cpl_table *, const char *, 
-                                     cpl_size, cpl_size, double complex);
+                                     cpl_size, cpl_size, _Complex double);
 cpl_error_code cpl_table_fill_column_window_float_complex(cpl_table *, 
-                     const char *, cpl_size, cpl_size, float complex);
+                     const char *, cpl_size, cpl_size, _Complex float);
 cpl_error_code cpl_table_fill_column_window_double_complex(cpl_table *, 
-                     const char *, cpl_size, cpl_size, double complex);
+                     const char *, cpl_size, cpl_size, _Complex double);
 #endif
 cpl_error_code cpl_table_fill_column_window_string(cpl_table *, const char *, 
                                       cpl_size, cpl_size, const char *);
@@ -210,9 +210,9 @@ cpl_error_code cpl_table_copy_data_double(cpl_table *, const char *,
                                           const double *);
 #ifdef _Complex_I
 cpl_error_code cpl_table_copy_data_float_complex(cpl_table *, const char *, 
-                                                 const float complex *);
+                                                 const _Complex float *);
 cpl_error_code cpl_table_copy_data_double_complex(cpl_table *, const char *, 
-                                                  const double complex *);
+                                                  const _Complex double *);
 #endif
 cpl_error_code cpl_table_copy_data_string(cpl_table *, const char *, 
                                           const char **);
@@ -239,9 +239,9 @@ cpl_error_code cpl_table_fill_invalid_double(cpl_table *, const char *,
                                                  double);
 #ifdef _Complex_I
 cpl_error_code cpl_table_fill_invalid_float_complex(cpl_table *, const char *, 
-                                                float complex);
+                                                _Complex float);
 cpl_error_code cpl_table_fill_invalid_double_complex(cpl_table *, const char *, 
-                                                 double complex);
+                                                 _Complex double);
 #endif
 
 cpl_error_code cpl_table_erase_column(cpl_table *, const char *);
@@ -252,7 +252,7 @@ cpl_error_code cpl_table_duplicate_column(cpl_table *, const char *,
 cpl_error_code cpl_table_name_column(cpl_table *, const char *, const char *);
 int cpl_table_has_column(const cpl_table *, const char *);
 
-const char *cpl_table_get_column_name(const cpl_table *);
+const char *cpl_table_get_column_name(const cpl_table *) CPL_ATTR_DEPRECATED;
 cpl_array *cpl_table_get_column_names(const cpl_table *table);
 
 cpl_error_code cpl_table_set_size(cpl_table *, cpl_size);
@@ -289,13 +289,13 @@ cpl_error_code cpl_table_multiply_scalar(cpl_table *, const char *, double);
 cpl_error_code cpl_table_divide_scalar(cpl_table *, const char *, double);
 #ifdef _Complex_I
 cpl_error_code cpl_table_add_scalar_complex(cpl_table *, 
-                                            const char *, double complex);
+                                            const char *, _Complex double);
 cpl_error_code cpl_table_subtract_scalar_complex(cpl_table *, 
-                                                 const char *, double complex);
+                                                 const char *, _Complex double);
 cpl_error_code cpl_table_multiply_scalar_complex(cpl_table *, 
-                                                 const char *, double complex);
+                                                 const char *, _Complex double);
 cpl_error_code cpl_table_divide_scalar_complex(cpl_table *, 
-                                               const char *, double complex);
+                                               const char *, _Complex double);
 #endif
 cpl_error_code cpl_table_abs_column(cpl_table *, const char *);
 cpl_error_code cpl_table_logarithm_column(cpl_table *, const char *, double);
@@ -317,7 +317,7 @@ cpl_error_code cpl_table_get_column_minpos(const cpl_table *,
                                            const char *, cpl_size *);
 
 #ifdef _Complex_I
-double complex cpl_table_get_column_mean_complex(const cpl_table *, 
+_Complex double cpl_table_get_column_mean_complex(const cpl_table *, 
                                                  const char *);
 #endif
 double cpl_table_get_column_mean(const cpl_table *, const char *);
@@ -357,13 +357,13 @@ cpl_size cpl_table_or_selected_double(cpl_table *, const char *,
                                      cpl_table_select_operator, double);
 #ifdef _Complex_I
 cpl_size cpl_table_and_selected_float_complex(cpl_table *, const char *, 
-                                    cpl_table_select_operator, float complex);
+                                    cpl_table_select_operator, _Complex float);
 cpl_size cpl_table_or_selected_float_complex(cpl_table *, const char *, 
-                                    cpl_table_select_operator, float complex);
+                                    cpl_table_select_operator, _Complex float);
 cpl_size cpl_table_and_selected_double_complex(cpl_table *, const char *, 
-                                     cpl_table_select_operator, double complex);
+                                     cpl_table_select_operator, _Complex double);
 cpl_size cpl_table_or_selected_double_complex(cpl_table *, const char *, 
-                                     cpl_table_select_operator, double complex);
+                                     cpl_table_select_operator, _Complex double);
 #endif
 
 cpl_size cpl_table_and_selected_string(cpl_table *, const char *, 
