@@ -947,7 +947,7 @@ CPL_BEGIN_DECLS
 /**
    @hideinitializer
    @ingroup cpl_test
-   @brief  Evaluate an expression and return if it fails
+   @brief  Evaluate an expression and terminate the process if it fails
    @param  bool   The (boolean) expression to evaluate, side-effects are allowed
    @note   A zero value of the expression is a failure, other values are not
    @return void
@@ -983,7 +983,7 @@ CPL_BEGIN_DECLS
         cpl_test_macro(cpl_test_errno, cpl_test_time, cpl_test_flops,   \
                        cpl_test_state, cpl_test_ok, CPL_TRUE, #bool,    \
                        cpl_func, __FILE__, __LINE__);                   \
-        if (cpl_test_ok == CPL_FALSE) return cpl_test_end(0);           \
+        if (cpl_test_ok == CPL_FALSE) exit(cpl_test_end(0));            \
     } while (0)
 
 
