@@ -80,8 +80,9 @@
         "|ORIGIN[0-9]*)$"
 
 #define CPL_FITS_COMPRKEYS  "^(" "ZIMAGE|ZCMPTYPE|ZNAXIS" \
-        "|ZTENSION|ZPCOUNT|ZGCOUNT|ZNAME[0-9]|ZVAL[0-9]|" \
-        "ZTILE[0-9]|ZBITPIX|ZNAXIS[0-9]|ZSCALE|ZZERO|ZBLANK" ")$"
+        "|ZTENSION|ZPCOUNT|ZGCOUNT|ZNAME[0-9]|ZVAL[0-9]"  \
+        "|ZTILE[0-9]|ZBITPIX|ZNAXIS[0-9]|ZSCALE|ZZERO"    \
+        "|ZBLANK|ZHECKSUM|ZDATASUM" ")$"
 
 
 /* CFITSIO support for I/O of largest possible buffers. */
