@@ -157,7 +157,7 @@ CPL_TYPE ADDTYPE(cpl_tools_get_median)(CPL_TYPE * self, cpl_size n)
 
     return (n & 1)
         ? self[(n-1)/2] /* Odd number */
-        : (self[n/2-1]+self[n/2])/((CPL_TYPE)2); /* Even number */
+        : self[n/2-1] + (self[n/2]-self[n/2-1])/((CPL_TYPE)2); /* Even number */
 }
 
 
