@@ -1,4 +1,5 @@
-/* $Id: cpl_type.h,v 1.29 2012/05/09 09:59:26 llundin Exp $
+/* $Id: cpl_type.h,v 1.29 2012-05-09 09:59:26 llundin Exp $
+ *
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -20,9 +21,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/05/09 09:59:26 $
+ * $Date: 2012-05-09 09:59:26 $
  * $Revision: 1.29 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifndef CPL_TYPE_H
@@ -31,7 +32,6 @@
 #include <cxtypes.h>
 #include <cpl_macros.h>
 
-
 CPL_BEGIN_DECLS
 
 /**@{*/
@@ -159,6 +159,12 @@ enum _cpl_type_ {
      */
     CPL_TYPE_UNSPECIFIED = 1 << 20,
 
+    /**
+     * Type code corresponding to type @c cpl_bitmask
+     * @hideinitializer
+     */
+    CPL_TYPE_BITMASK     = 1 << 21,
+
     /**
      * Type code corresponding to a character array.
      * @hideinitializer
@@ -212,7 +218,19 @@ typedef long long cpl_size;
 
 #endif
 
+#include <stdint.h>
 
+/*----------------------------------------------------------------------------*/
+/**
+ * 
+ * @brief The CPL bitmask type for bitmask operations
+ * @note The CPL bitmask is currently used only for bit-wise operations on CPL
+ * images of integer pixel type, which are 32-bits wide.
+ * For forward compatibility the CPL bitmask is 64 bits wide, which is cast to
+ * 32 bits when used with a CPL_TYPE_INT.
+ */
+/*----------------------------------------------------------------------------*/
+typedef uint64_t cpl_bitmask;
 
 /**
  * @def CPL_SIZE_MIN
