@@ -1,4 +1,4 @@
-/* $Id: cpl_vector_fit_impl.h,v 1.13 2012/06/13 12:51:53 llundin Exp $
+/* $Id: cpl_vector_fit_impl.h,v 1.15 2013-02-26 19:25:41 cgarcia Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2012/06/13 12:51:53 $
- * $Revision: 1.13 $
- * $Name: cpl-6_3_1 $
+ * $Author: cgarcia $
+ * $Date: 2013-02-26 19:25:41 $
+ * $Revision: 1.15 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifndef CPL_VECTOR_FIT_IMPL_H
@@ -51,8 +51,9 @@
 #include "cpl_error_impl.h"
 #include "cpl_errorstate.h"
 
-#include <assert.h>
 
+#include <assert.h>
+#include <math.h>
 /*----------------------------------------------------------------------------*/
 /*
    @brief   Get new position in parameter space (L-M algorithm)
@@ -575,7 +576,11 @@ cpl_fit_lvmq_(const cpl_matrix *x, const cpl_matrix *sigma_x,
            (and lambda and count from above), the loop will terminate */
 
         double chi_sq_candidate = 0.0;
-        int cont = 1; /* continue? */
+        double chi_sq_diff;
+        int canderror;
+        int cont = 3; /* Try to get a candidate this many times */
+
+
 
         /* Get candidate position in parameter space = a+da,
          * where  alpha * da = beta .
@@ -583,49 +588,41 @@ cpl_fit_lvmq_(const cpl_matrix *x, const cpl_matrix *sigma_x,
          */
 
         do {
-        cpl_errorstate prevstate = cpl_errorstate_get();
+            cpl_errorstate prevstate = cpl_errorstate_get();
+            canderror = get_candidate(a_data, ia_local,
+                                      M, N, D,
+                                      lambda, f, dfda,
+                                      x_data, y_data, sigma_data,
+                                      part, alpha, beta, a_da);
+            cont--;
 
-        get_candidate(a_data, ia_local,
-                  M, N, D,
-                  lambda, f, dfda,
-                  x_data, y_data, sigma_data,
-                  part, alpha, beta, a_da);
+            if (canderror || !cpl_errorstate_is_equal(prevstate)) {
+                if (cont > 0 && !cpl_errorstate_is_equal(prevstate) &&
+                    cpl_error_get_code() == CPL_ERROR_SINGULAR_MATRIX &&
+                    lambda < MAXLAMBDA) {
+                    /* Recover since lambda did not diverge */
+                    lambda *= 9.0;
+                    cpl_errorstate_set(prevstate);
+                    canderror = 1; /* Ensure another try */
+                } else {
+                    cpl_free(ia_local);
+                    cpl_matrix_delete(alpha);
+                    cpl_matrix_delete(beta);
+                    cpl_free(a_da);
+                    cpl_free(part);
 
-        cont = 0;
-        if (!cpl_errorstate_is_equal(prevstate) &&
-            cpl_error_get_code() == CPL_ERROR_SINGULAR_MATRIX)
-            /* Handle this one */
-            {
-            if (lambda < MAXLAMBDA)
-                {
-                cont = 1;
-                lambda *= 9.0;
-                }
-            else
-                {
-                /* Set error if lambda diverged */
-                cpl_free(ia_local);
-                cpl_matrix_delete(alpha);
-                cpl_matrix_delete(beta);
-                cpl_free(a_da);
-                cpl_free(part);
-                return cpl_error_set_(CPL_ERROR_CONTINUE);
+                    /* Set error either if lambda diverged or if 
+                       get_candidate() failed in some other way */
+                    return cpl_error_set_message_(cpl_error_get_code() ==
+                                                  CPL_ERROR_SINGULAR_MATRIX
+                                                  ? CPL_ERROR_CONTINUE
+                                                  : cpl_error_get_code(),
+                                                  "get_candidate()=%d. cont=%d. "
+                                                  "lambda = %g", canderror, cont,
+                                                  lambda);
                 }
             }
-        else if (!cpl_errorstate_is_equal(prevstate))
-            {
-            /* Exceptional error from get_candidate() */
-            {
-                cpl_free(ia_local);
-                cpl_matrix_delete(alpha);
-                cpl_matrix_delete(beta);
-                cpl_free(a_da);
-                cpl_free(part);
-                return cpl_error_set_where_();
-            }
-            }
-
-        } while(cont);
+        } while (canderror);
 
         /* Get chi^2(a+da) */
         chi_sq_candidate = get_chisq(N, D, f, a_da, x_data, y_data, sigma_data);
@@ -642,7 +639,8 @@ cpl_fit_lvmq_(const cpl_matrix *x, const cpl_matrix *sigma_x,
                 : cpl_error_set_(CPL_ERROR_CONTINUE);
         }
 
-        if (chi_sq_candidate > chi_sq)
+	chi_sq_diff = chi_sq_candidate - chi_sq;
+        if (chi_sq_diff > sqrt(DBL_EPSILON) )
         {
             /* Move towards steepest descent */
             lambda *= 9.0;
@@ -654,7 +652,7 @@ cpl_fit_lvmq_(const cpl_matrix *x, const cpl_matrix *sigma_x,
 
             /* Count the number of successive improvements in chi^2 of
                less than 0.01 (default) relative */
-            if ( chi_sq == 0 ||
+            if ( chi_sq < sqrt(DBL_EPSILON) ||
              (chi_sq - chi_sq_candidate)/chi_sq < relative_tolerance)
             {
                 count += 1;
@@ -674,6 +672,7 @@ cpl_fit_lvmq_(const cpl_matrix *x, const cpl_matrix *sigma_x,
             chi_sq = chi_sq_candidate;
         }
         iterations++;
+
     }
 
     /* Set error if we didn't converge */
@@ -820,6 +819,7 @@ cpl_fit_lvmq_(const cpl_matrix *x, const cpl_matrix *sigma_x,
         cpl_matrix_delete(cov);
     }
 
+
     cpl_free(ia_local);
     cpl_matrix_delete(alpha);
     cpl_matrix_delete(beta);
