@@ -569,6 +569,49 @@ static void cpl_imagelist_collapse_median_create_tests(cpl_size mz,
 
     }
 
+    /* small (< L2 cache) imagelist test */
+    {
+        cpl_imagelist * l = cpl_imagelist_new();
+        cpl_imagelist * lb = cpl_imagelist_new();
+        size_t i, j, k;
+        int rej;
+        cpl_image * med, * medb;
+        for (i = 0; i < 107; i++) {
+            cpl_image * img = cpl_image_new(7, 13, CPL_TYPE_FLOAT);
+            cpl_image * imgb = cpl_image_new(7, 13, CPL_TYPE_FLOAT);
+            for (j = 0; j < 7; j++) {
+                for (k = 0; k < 13; k++) {
+                    cpl_image_set(img, j + 1, k + 1, k * 13 + j + i);
+                    cpl_image_set(imgb, j + 1, k + 1, k * 13 + j + i);
+                }
+            }
+            cpl_image_reject(imgb, 4, 12);
+            cpl_image_reject(imgb, 5, 9);
+            if (i == 3)
+                cpl_image_reject(imgb, 7, 10);
+            cpl_imagelist_set(l, img, i);
+            cpl_imagelist_set(lb, imgb, i);
+        }
+        med = cpl_imagelist_collapse_median_create(l);
+        medb = cpl_imagelist_collapse_median_create(lb);
+
+        for (j = 0; j < 7; j++) {
+            for (k = 0; k < 13; k++) {
+                cpl_test_eq(cpl_image_get(med, j + 1, k + 1, &rej),
+                            k * 13 + j + 107 / 2);
+            }
+        }
+        cpl_image_set(med, 7, 10, cpl_image_get(med, 7, 10, &rej) + 0.5);
+        cpl_test_image_abs(med, medb, 0);
+        cpl_test(cpl_image_is_rejected(medb, 4, 12));
+        cpl_test(cpl_image_is_rejected(medb, 5, 9));
+
+        cpl_image_delete(med);
+        cpl_image_delete(medb);
+        cpl_imagelist_delete(l);
+        cpl_imagelist_delete(lb);
+    }
+
     return;
 
 }
