@@ -1,4 +1,4 @@
-/* $Id: cpl_imagelist_io-test.c,v 1.58 2013/02/22 14:29:33 llundin Exp $
+/* $Id: cpl_imagelist_io-test.c,v 1.61 2013-04-26 08:24:00 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2013/02/22 14:29:33 $
- * $Revision: 1.58 $
- * $Name: cpl-6_3_1 $
+ * $Date: 2013-04-26 08:24:00 $
+ * $Revision: 1.61 $
+ * $Name: not supported by cvs2svn $
  */
 
 /*-----------------------------------------------------------------------------
@@ -203,7 +203,7 @@ int main(void)
 
     /* Test cpl_imagelist_set() */
     for (i=0; i < NIMAGES; i++) {
-        cpl_image * copy = cpl_image_duplicate(image);
+        cpl_image * copy = cpl_image_fill_test_create(IMAGESZ, IMAGESZ);
 
         flags[i] = i % 2 ? 1.0 : -1.0;
 
@@ -756,11 +756,11 @@ static void cpl_imagelist_save_compression_test(void)
 
 /*----------------------------------------------------------------------------*/
 /**
-  @brief    Benchmar saving with compression
+  @brief    Benchmark saving with compression
   @param  nx NX
   @param  ny NY
   @param  nz NZ
-  @param  nr Number of repetions
+  @param  nr Number of repetitions
   @return   void
   @see cpl_image_save()
  */
@@ -773,7 +773,7 @@ static void cpl_imagelist_save_compression_bench(cpl_size nx, cpl_size ny,
     cpl_imagelist * imglist = cpl_imagelist_new();
     cpl_error_code error;
     cpl_size i;
-    double tsum;
+    double tsum = 0.0;
 
     error = cpl_image_fill_noise_uniform(img, 0.0, 255.0);
     cpl_test_eq_error(error, CPL_ERROR_NONE);
@@ -794,7 +794,7 @@ static void cpl_imagelist_save_compression_bench(cpl_size nx, cpl_size ny,
     cpl_test_eq( cpl_fits_count_extensions(FILENAME), 1);
 
 #ifdef _OPENMP
-#pragma omp parallel for private(i)
+#pragma omp parallel for private(i) reduction(+ : tsum)
 #endif
     for (i = 0; i < nr; i++) {
         const double t0 = cpl_test_get_walltime();
