@@ -1144,16 +1144,12 @@ static void cpl_mask_filter_test(int nsize)
         error = cpl_mask_filter(copy1, mask1, id, filter[k], CPL_BORDER_ZERO);
         cpl_test_eq_error(error, CPL_ERROR_DATA_NOT_FOUND);
 
-        /* Error: Unsupported boder mode */
+        /* Error: Unsupported border modes */
         error = cpl_mask_filter(copy1, mask1, id, filter[k], CPL_BORDER_CROP);
         cpl_test_eq_error(error, CPL_ERROR_UNSUPPORTED_MODE);
 
-        if (filter[k] == CPL_FILTER_OPENING ||
-            filter[k] == CPL_FILTER_CLOSING) {
-            error = cpl_mask_filter(copy1, mask1, id, filter[k],
-                                    CPL_BORDER_NOP);
-            cpl_test_eq_error(error, CPL_ERROR_UNSUPPORTED_MODE);
-        }
+        error = cpl_mask_filter(copy1, mask1, id, filter[k], CPL_BORDER_FILTER);
+        cpl_test_eq_error(error, CPL_ERROR_UNSUPPORTED_MODE);
 
         /* The identity kernel */
         error = cpl_mask_not(id);
@@ -1164,6 +1160,12 @@ static void cpl_mask_filter_test(int nsize)
         cpl_test_eq_error(error, CPL_ERROR_NONE);
         cpl_test_eq_mask(copy1, mask1);
 
+        /* Rely on the border already being equal to the reference */
+        error = cpl_mask_filter(copy1, mask1, id, filter[k], CPL_BORDER_NOP);
+
+        cpl_test_eq_error(error, CPL_ERROR_NONE);
+        cpl_test_eq_mask(copy1, mask1);
+
         cpl_mask_delete(evenr);
         cpl_mask_delete(evenc);
         cpl_mask_delete(copy2);
