@@ -153,7 +153,7 @@ void cpl_plot_test_all(int n2d, int nvec, int nrow)
     for (i=0; i < nrow; i++) {
         cpl_table_set_double(tab, names[0], i, (double)(10*i+1));
         cpl_table_set_double(tab, names[1], i, sin(10*i+1)/10*i+1);
-        cpl_table_set_double(tab, names[2], i, log(i+1)/i+1);
+        cpl_table_set_double(tab, names[2], i, log1p(i)/i+1);
     }
 
     /* No errors should have happened in the plot preparation */
