@@ -1180,7 +1180,7 @@ static cpl_polynomial * cpl_polynomial_fit_test_2d(FILE * stream,
             cpl_test_zero( cpl_matrix_set(xy_pos, 0, k, (double)i+xy_offset) );
             cpl_test_zero( cpl_matrix_set(xy_pos, 1, k, (double)j-xy_offset) );
 
-            cpl_test_zero( cpl_vector_set(vec,   k, sqrt(x)*log(y+1.0)));
+            cpl_test_zero( cpl_vector_set(vec,   k, sqrt(x)*log1p(y)));
         }
     }
 
@@ -1658,7 +1658,7 @@ static void cpl_polynomial_fit_bench_2d(cpl_size nr, cpl_size nc, cpl_size nd)
             error = cpl_matrix_set(xy_pos, 1, k, (double)j);
             cpl_test_eq_error(error, CPL_ERROR_NONE);
 
-            error = cpl_vector_set(vec,   k, sqrt(x)*log(y+1.0));
+            error = cpl_vector_set(vec,   k, sqrt(x)*log1p(y));
             cpl_test_eq_error(error, CPL_ERROR_NONE);
         }
     }
