@@ -248,7 +248,7 @@ cpl_error_code cpl_dfs_save_image(cpl_frameset            * allframes,
   @param  filename   Filename of created product
   @note remregexp may be NULL
   @return CPL_ERROR_NONE or the relevant CPL error code on error
-  @see cpl_dfs_image_save(), cpl_propertylistlist_save().
+  @see cpl_dfs_save_image(), cpl_propertylist_save().
 
   The FITS header of the created product is created from the provided applist
   and the cards copied by cpl_dfs_setup_product_header(), with exception of
@@ -293,7 +293,7 @@ cpl_error_code cpl_dfs_save_propertylist(cpl_frameset            * allframes,
   @param  filename   Filename of created product
   @note remregexp may be NULL
   @return CPL_ERROR_NONE or the relevant CPL error code on error
-  @see cpl_dfs_image_save(), cpl_imagelist_save().
+  @see cpl_dfs_save_image(), cpl_imagelist_save().
 
  */
 /*----------------------------------------------------------------------------*/
