@@ -88,6 +88,41 @@ CPL_BEGIN_DECLS
 #define CPL_DFS_PRO_SCIENCE "ESO PRO SCIENCE"
 
 
+/**
+ * @ingroup cpl_dfs
+ *
+ * @brief
+ *  Pipeline products digital signature flags.
+ *
+ * Flags to select the different digital signatures to compute for pipeline
+ * product files. The values may be combined using bitwise or.
+ */
+
+enum {
+
+    /**
+     * Do not compute any signatures
+     * @hideinitializer
+     */
+
+    CPL_DFS_SIGNATURE_NONE     = 0,
+
+    /**
+     * Compute the DATAMD5 data hash
+     * @hideinitializer
+     */
+
+    CPL_DFS_SIGNATURE_DATAMD5  = 1 << 0,
+
+    /**
+     * Compute FITS standard CHECKSUM and DATASUM
+     * @hideinitializer
+     */
+
+    CPL_DFS_SIGNATURE_CHECKSUM = 1 << 1
+};
+
+
 /*-----------------------------------------------------------------------------
                               Function prototypes
  -----------------------------------------------------------------------------*/
@@ -156,6 +191,9 @@ cpl_error_code cpl_dfs_setup_product_header(cpl_propertylist *,
 
 cpl_error_code cpl_dfs_update_product_header(cpl_frameset *);
 
+cpl_error_code cpl_dfs_sign_products(const cpl_frameset *set,
+                                      unsigned int flags);
+
 CPL_END_DECLS
 
 #endif
