@@ -1,4 +1,4 @@
-/* $Id: md5.h,v 1.5 2010/11/11 09:23:18 llundin Exp $
+/* $Id: md5.h,v 1.5 2010-11-11 09:23:18 llundin Exp $
  *
  * This file is part of the ESO CPL Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2010/11/11 09:23:18 $
+ * $Date: 2010-11-11 09:23:18 $
  * $Revision: 1.5 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifndef MD5_H
@@ -36,10 +36,15 @@ struct MD5Context {
     unsigned char in[64];
 };
 
-static void MD5Init(struct MD5Context *context);
-static void MD5Update(struct MD5Context *context, unsigned char const *buf,
-                      unsigned len);
-static void MD5Final(unsigned char digest[16], struct MD5Context *context);
+static void MD5Init(struct MD5Context * restrict context)
+    CPL_ATTR_NONNULL;
+static void MD5Update(struct MD5Context * restrict context,
+                      unsigned char const * restrict buf,
+                      unsigned len)
+    CPL_ATTR_NONNULL;
+static void MD5Final(unsigned char * restrict digest,
+                     struct MD5Context * restrict context)
+    CPL_ATTR_NONNULL;
 
 /*
  * This is needed to make RSAREF happy on some MS-DOS compilers.
