@@ -233,10 +233,10 @@ static cpl_error_code cpl_fft_image_(cpl_image * self, const cpl_image * other,
     cpl_ensure_code((cpl_size)nxout == lnxout, CPL_ERROR_UNSUPPORTED_MODE);
     cpl_ensure_code((cpl_size)nyout == lnyout, CPL_ERROR_UNSUPPORTED_MODE);
 
-    if (mode & CPL_FFT_FORWARD && !(typin & CPL_TYPE_COMPLEX)) {
+    if ((mode & CPL_FFT_FORWARD) && !(typin & CPL_TYPE_COMPLEX)) {
         cpl_ensure_code(nxin == nxout || nxout == nxh,
                         CPL_ERROR_INCOMPATIBLE_INPUT);
-    } else if (mode & CPL_FFT_BACKWARD && !(typout & CPL_TYPE_COMPLEX)) {
+    } else if ((mode & CPL_FFT_BACKWARD) && !(typout & CPL_TYPE_COMPLEX)) {
         cpl_ensure_code(nxin == nxout || nxin == nxh,
                         CPL_ERROR_INCOMPATIBLE_INPUT);
     } else {
