@@ -114,20 +114,27 @@ struct _cpl_wcs_ {
     struct wcsprm *wcsptr;   /* WCSLIB structure */
     int           istab;     /* Set if header is from a table */
     int           naxis;     /* Number of dimensions of the image */
-    int           *dims;     /* Dimensions of image */
-    cpl_array     *imdims;     /* Wrapper for image dimensions */
-    cpl_array     *crval;     /* CRVALia keyvalues for each coord axis */
-    cpl_array     *crpix;     /* CRPIXja keyvalues for each pixel axis */
-    cpl_array     *ctype;     /* CTYPEja keyvalues for each pixel axis */
-    cpl_array     *cunit;     /* CUNITja keyvalues for each pixel axis */
-    cpl_matrix    *cd;         /* CDi_ja linear transformation matrix */
+    cpl_array     *imdims;   /* Dimensions of image */
+    cpl_array     *crval;    /* CRVALia keyvalues for each coord axis */
+    cpl_array     *crpix;    /* CRPIXja keyvalues for each pixel axis */
+    cpl_array     *ctype;    /* CTYPEja keyvalues for each pixel axis */
+    cpl_array     *cunit;    /* CUNITja keyvalues for each pixel axis */
+    cpl_matrix    *cd;       /* CDi_ja linear transformation matrix */
 };
 
 /*----------------------------------------------------------------------------
                                    Private functions
  ----------------------------------------------------------------------------*/
 
-static cpl_wcs *cpl_wcs_init(void) CPL_ATTR_ALLOC;
+inline static cpl_wcs *_cpl_wcs_init(struct wcsprm *wcs,
+                                     int is_tab) CPL_ATTR_ALLOC;
+
+inline static int _cpl_wcs_set_ctype(cpl_wcs *self);
+inline static int _cpl_wcs_set_cunit(cpl_wcs *self);
+inline static int _cpl_wcs_set_cd(cpl_wcs *self);
+
+inline static int _cpl_wcsset(cpl_wcs *wcs);
+
 
 /* Fix when cfitsio is upgraded */
 /* static char *cpl_wcs_plist2fitsstr(const cpl_propertylist *self); */
@@ -140,7 +147,6 @@ static void cpl_wcs_platesol_4(const cpl_matrix *xy, const cpl_matrix *std,
 static void cpl_wcs_platesol_6(const cpl_matrix *xy, const cpl_matrix *std,
                                const cpl_array *bad, cpl_array **plateconsts)
     CPL_ATTR_NONNULL;
-static int _cpl_wcsset(cpl_wcs *wcs);
 
 #ifdef fits_write_hdu
   /* fits_write_hdu() was introduced in CFITSIO version 3.03 */
@@ -219,14 +225,19 @@ static int cpl_wcs_ffhdr2str(fitsfile *fptr, int exclude_comm, char **exclist,
 
 cpl_wcs *cpl_wcs_new_from_propertylist(const cpl_propertylist *plist) {
 #ifdef CPL_WCS_INSTALLED    /* If WCS is installed */
+
     char *shdr;
-    cpl_wcs *wcs;
-    cpl_propertylist *testp;
     int retval,nrej,nwcs;
     int np = 0;
     int istab = -1;
+
+    cpl_propertylist *testp = NULL;
+
+    cpl_wcs *wcs = NULL;
+
     struct wcsprm *wwcs = NULL;
 
+
     /* Check to see if the propertylist exists */
 
     cpl_ensure(plist != NULL, CPL_ERROR_NULL_INPUT, NULL);
@@ -236,7 +247,7 @@ cpl_wcs *cpl_wcs_new_from_propertylist(const cpl_propertylist *plist) {
     testp = cpl_propertylist_new();
     if (!cpl_propertylist_copy_property_regexp(testp, plist, "^CRVAL", 0)
         && cpl_propertylist_get_size(testp) > 0) {
-	istab = 0;
+        istab = 0;
     } else if (!cpl_propertylist_copy_property_regexp(testp, plist, "^TCRVL", 0)
                && cpl_propertylist_get_size(testp) > 0) {
         istab = 1;
@@ -246,89 +257,67 @@ cpl_wcs *cpl_wcs_new_from_propertylist(const cpl_propertylist *plist) {
         (void)cpl_error_set_(CPL_ERROR_UNSPECIFIED);
     }
     cpl_propertylist_delete(testp);
-    if (istab < 0) return NULL;
 
-    /* Get a cpl_wcs structure and initialise it */
+    if (istab < 0) {
+        return NULL;
+    }
 
-    wcs = cpl_wcs_init();
 
     /* Convert the propertylist into a string */
 
     shdr = cpl_wcs_plist2fitsstr(plist, &np);
     if (shdr == NULL) {
         cpl_error_set_where_();
-        cpl_wcs_delete(wcs);
-        return(NULL);
-    }
-
-    /* Parse the header to get the wcslib structure */
-
-    if (! istab)
-	retval = wcspih(shdr,np,0,0,&nrej,&nwcs,&wwcs);
-    else
-	retval = wcsbth(shdr,np,0,0,0,NULL,&nrej,&nwcs,&wwcs);
-    free(shdr);
-    if (retval != 0) {
-        wcsvfree(&nwcs,&wwcs);
-        cpl_wcs_delete(wcs);
-	if (istab)
-	    (void)cpl_error_set_wcs(CPL_ERROR_UNSPECIFIED, retval,
-				    "wcsbth", "np=%d", np);
-	else
-	    (void)cpl_error_set_wcs(CPL_ERROR_UNSPECIFIED, retval,
-				    "wcspih", "np=%d", np);
         return NULL;
     }
-    wcs->istab = istab;
 
-    /* Now extract the one you want and ditch the rest */
 
-    wcs->wcsptr = (struct wcsprm *)cpl_calloc(1,sizeof(struct wcsprm));
-    (wcs->wcsptr)->flag = -1;
-    wcscopy(1,wwcs,wcs->wcsptr);
-    wcsset(wcs->wcsptr);
+    /*
+     * Parse the header string to get all WCS representations which are
+     * present. The number of WCS representations is stored in nwcs.
+     */
+
+    if (!istab) {
+        retval = wcspih(shdr,np,0,0,&nrej,&nwcs,&wwcs);
+    }
+    else {
+        retval = wcsbth(shdr,np,0,0,0,NULL,&nrej,&nwcs,&wwcs);
+    }
+    free(shdr);
+
+    if (retval != 0) {
+        wcsvfree(&nwcs,&wwcs);
+
+        if (istab) {
+            (void)cpl_error_set_wcs(CPL_ERROR_UNSPECIFIED, retval,
+                                    "wcsbth", "np=%d", np);
+        }
+        else {
+            (void)cpl_error_set_wcs(CPL_ERROR_UNSPECIFIED, retval,
+                                    "wcspih", "np=%d", np);
+        }
+        return NULL;
+    }
+
+
+    /*
+     * Create and initialize the cpl_wcs object.
+     *
+     * Only the first WCS representation which was found in the header is used
+     * and all others are ignored, i.e. the first element of the WCS vector
+     * wwcs is copied to the cpl_wcs object, then all extra wcsprm
+     * structures present in wwcs are discarded by deallocating the
+     * temporary buffers.
+     */
+
+    wcs = _cpl_wcs_init(wwcs, istab);
+
     wcsvfree(&nwcs,&wwcs);
 
-    wcs->naxis = wcs->wcsptr->naxis;
-
     if (wcs->naxis > 0) {
 
-        int k = 0;
+        if (!istab) {
 
-        /* If this is a table, then just copy the vital WCS information over
-           and leave the image dimensional information as NULL */
-
-        wcs->crval = cpl_array_wrap_double(wcs->wcsptr->crval, wcs->naxis);
-        wcs->crpix = cpl_array_wrap_double(wcs->wcsptr->crpix, wcs->naxis);
-        wcs->cd    = cpl_matrix_wrap(wcs->naxis, wcs->naxis,
-                                     wcs->wcsptr->lin.piximg);
-
-        /*
-         * Make the contents of CUNITia and CTYPEia available through
-         * accessors.
-         *
-         * Due to the way wcslib stores this information, wrapping
-         * wcsptr->cunit and wcsptr->ctype is not possible, and therefore
-         * the elements have to be copied.
-         *
-         * NOTE: The elements of wcsptr->cuint and wcsptr->ctype get updated
-         * when wcsset() is called. Thus the copy has to be updated after each
-         * call to wcsset()!
-         *
-         * Apart from this function where the structure is initially created
-         * use _cpl_wcsset() to make sure that the copied fields get properly
-         * updated
-         */
-
-        wcs->ctype = cpl_array_new(wcs->naxis, CPL_TYPE_STRING);
-        wcs->cunit = cpl_array_new(wcs->naxis, CPL_TYPE_STRING);
-
-        for (k = 0; k < wcs->naxis; ++k) {
-            cpl_array_set_string(wcs->ctype, k, wcs->wcsptr->ctype[k]);
-            cpl_array_set_string(wcs->cunit, k, wcs->wcsptr->cunit[k]);
-        }
-
-        if (! istab ) {
             cpl_errorstate prevstate = cpl_errorstate_get();
 
             /* This is an image, see if it's a compressed image */
@@ -340,7 +329,7 @@ cpl_wcs *cpl_wcs_new_from_propertylist(const cpl_propertylist *plist) {
 
             /* Now copy the stuff over to someplace where we can get it */
 
-            wcs->dims = cpl_malloc((size_t)wcs->naxis * sizeof(int));
+            int *dims = cpl_array_get_data_int(wcs->imdims);
 
             /* Get the image size information */
 
@@ -351,34 +340,30 @@ cpl_wcs *cpl_wcs_new_from_propertylist(const cpl_propertylist *plist) {
 
                 i--;
 
-                wcs->dims[i] = inax;
+                dims[i] = inax;
 
                 (void)sprintf(naxd, "%d", i); /* Cannot overflow buffer */
             }
 
             cpl_free(nax);
 
+
+            /*
+             * If any axis dimension is missing, clear the image dimensional
+             * information and reset the number of axis to 0
+             */
+
             if (i > 0) {
-                /* Set the image dimensional information as NULL */
                 cpl_errorstate_set(prevstate);
-                cpl_free(wcs->dims);
-                wcs->dims = NULL;
-                wcs->imdims = NULL;
+                cpl_array_fill_window(wcs->imdims, 0,
+                                      cpl_array_get_size(wcs->imdims), 0);
                 wcs->naxis = 0; /* crval, crpix and cd are still non-NULL */
-            } else {
-                wcs->imdims = cpl_array_wrap_int(wcs->dims, wcs->naxis);
             }
+
         }
-    } else {
-        /* FIXME: Is it correct/necessary to set to NULL ? */
-        wcs->crval = NULL;
-        wcs->crpix = NULL;
-        wcs->ctype = NULL;
-        wcs->cunit = NULL;
-        wcs->cd    = NULL;
     }
 
-    return(wcs);
+    return wcs;
 
 #else
     cpl_ensure(plist != NULL, CPL_ERROR_NULL_INPUT, NULL);
@@ -418,17 +403,17 @@ void cpl_wcs_delete(cpl_wcs *wcs) {
 #ifdef CPL_WCS_INSTALLED    /* If WCS is installed */
     /* Free the workspace */
 
-    if (wcs->naxis != 0) {
-	cpl_free(wcs->dims);
-	cpl_array_unwrap(wcs->imdims);
+    if (wcs->imdims != NULL) {
+        cpl_array_delete(wcs->imdims);
     }
+
+    cpl_array_delete(wcs->cunit);
+    cpl_array_delete(wcs->ctype);
+
     cpl_array_unwrap(wcs->crval);
     cpl_array_unwrap(wcs->crpix);
 
-    cpl_array_delete(wcs->ctype);
-    cpl_array_delete(wcs->cunit);
-
-    cpl_matrix_unwrap(wcs->cd);
+    cpl_matrix_delete(wcs->cd);
 
     if (wcs->wcsptr != NULL) {
         (void)wcsfree(wcs->wcsptr);
@@ -980,7 +965,7 @@ cpl_error_code cpl_wcs_platesol(const cpl_propertylist *ilist,
                                                     CPL_TYPE_DOUBLE);
 
                 cpl_property_set_double(_p,
-                                        (wp->lin.piximg)[(i - 1) * 2 + (j - 1)]);
+                                        cpl_matrix_get(wcs->cd, i - 1, j - 1));
                 cpl_property_set_comment(_p, "Coordinate transformation matrix "
                                          "element");
 
@@ -1444,37 +1429,111 @@ const cpl_matrix *cpl_wcs_get_cd(const cpl_wcs *wcs) {
 /**
  * @internal
  * @brief
- *   Create an empty wcs structure.
+ *   Create a wcs object from an existing wcsprm structure.
+ *
+ * @param wcs     The wcsprm structure from which the object is created.
+ * @param is_tab  Flag indicating whether wcs originates from a table header.
  *
  * @return
- *   The output wcs structure
+ *   The created wcs object, or @c NULL in case the input structure @em wcs
+ *   is a @C NULL pointer.
  *
- * @error
- *   None
+ * Allocate and initialize a wcs object from the wcsprm structure @em wcs.
+ * A deep copy of @em wcs is used to initialize the wcs object, and thus
+ * the ownership of @em wcs is not transferred.
  *
- * This is a static routine that creates an empty cpl_wcs structure.
+ * The internal copy of wcs is updated to make sure it is in a consistent
+ * state. Then the ancilliary members of the wcs object are filled with
+ * their respective values.
  */
 
-static cpl_wcs *cpl_wcs_init(void) {
+inline static cpl_wcs *
+_cpl_wcs_init(struct wcsprm *wcs, int is_tab)
+{
 
-    /* Get the main structure workspace */
+    cpl_wcs *self = NULL;
 
-    cpl_wcs * self = (cpl_wcs *)cpl_malloc(sizeof(cpl_wcs));
+    if (wcs != NULL) {
 
-    /* Initialise the output structure */
+        struct wcsprm *_wcs = NULL;
 
-    self->istab = -1;
-    self->wcsptr = NULL;
-    self->naxis = 0;
-    self->dims = NULL;
-    self->imdims = NULL;
-    self->crval = NULL;
-    self->crpix = NULL;
-    self->ctype = NULL;
-    self->cunit = NULL;
-    self->cd = NULL;
+        self = cpl_calloc(1, sizeof *self);
+        self->wcsptr = cpl_calloc(1, sizeof(struct wcsprm));
 
-    return(self);
+        _wcs = self->wcsptr;
+        _wcs->flag = -1;
+
+        wcscopy(1, wcs, _wcs);
+        wcsset(_wcs);
+
+        self->istab = is_tab;
+        self->naxis = _wcs->naxis;
+
+        self->crpix  = NULL;
+        self->crval  = NULL;
+        self->cunit  = NULL;
+        self->ctype  = NULL;
+        self->cd     = NULL;
+        self->imdims = NULL;
+
+
+        if (self->naxis > 0) {
+
+            self->crpix = cpl_array_wrap_double(_wcs->crpix, self->naxis);
+            self->crval = cpl_array_wrap_double(_wcs->crval, self->naxis);
+
+            /*
+             * Provide an array interface for _wcs->cunit and _wcs->ctype.
+             *
+             * Due to the unfavorable way wcslib stores this information
+             * the respective members cannot be wrapped in an array, but
+             * they have to be copied.
+             *
+             * NOTE:
+             *   This also means that whenever the underlying wcs structure
+             *   is updated using wcsset(), these members have to be updated
+             *   to.
+             */
+
+            self->ctype  = cpl_array_new(self->naxis, CPL_TYPE_STRING);
+            self->cunit  = cpl_array_new(self->naxis, CPL_TYPE_STRING);
+
+            _cpl_wcs_set_ctype(self);
+            _cpl_wcs_set_cunit(self);
+
+
+            /*
+             * Provide a representation of the CD matrix.
+             *
+             * A local representation of the CD matrix is necessary since
+             * wcslib does not always provide this information in a way that
+             * wrapping a member of the underlying structure would work.
+             * For instance, the member _wcs->cd is only an input parameter,
+             * but is never updated with the calculated CD matrix. The
+             * linear transformation matrix member of _wcs->lin on the
+             * other hand is not set for certain cases, and thus may
+             * not always be accessible.
+             */
+
+            self->cd = cpl_matrix_new(self->naxis, self->naxis);
+            _cpl_wcs_set_cd(self);
+
+
+            /*
+             * If the WCS originates from an image provide the image
+             * dimensions, otherwise leave it as NULL.
+             */
+
+            if (self->istab == 0) {
+                self->imdims = cpl_array_new(self->naxis, CPL_TYPE_INT);
+                cpl_array_fill_window_int(self->imdims, 0, self->naxis, 0);
+            }
+
+        }
+
+    }
+
+    return self;
 }
 
 /**
@@ -1864,24 +1923,108 @@ static void cpl_wcs_platesol_4(const cpl_matrix *xy, const cpl_matrix *std,
 
 
 inline static int
-_cpl_wcsset(cpl_wcs *wcs)
+_cpl_wcs_set_cd(cpl_wcs *self)
 {
-    int k;
-    int status = wcsset(wcs->wcsptr);
+
+    register int k;
+
 
     /*
-     * Update indirectly, exported data which may have been updated by
-     * the call to wcsset().
+     * Calculate the elements of the CD matrix as the product of the
+     * CDELT diagonal matrix and the PC matrix, i.e.
+     *
+     * CD = CDELT * PC
      */
 
-    for (k = 0; k < wcs->naxis; ++k) {
-        cpl_array_set_string(wcs->ctype, k, wcs->wcsptr->ctype[k]);
-        cpl_array_set_string(wcs->cunit, k, wcs->wcsptr->cunit[k]);
+    for (k = 0; k < self->naxis; ++k) {
+
+        register int l;
+        register double _cdelt = self->wcsptr->lin.cdelt[k];
+
+        double *_pc    = &self->wcsptr->lin.pc[k * self->naxis];
+
+
+        for (l = 0; l < self->naxis; ++l) {
+            cpl_matrix_set(self->cd, k, l, _cdelt * _pc[l]);
+        }
+
     }
 
+    return 0;
+
+}
+
+
+inline static int
+_cpl_wcs_set_ctype(cpl_wcs *self)
+{
+
+    register int k;
+
+    for (k = 0; k < self->naxis; ++k) {
+        cpl_array_set_string(self->ctype, k, self->wcsptr->ctype[k]);
+    }
+
+    return 0;
+}
+
+
+inline static int
+_cpl_wcs_set_cunit(cpl_wcs *self)
+{
+
+    register int k;
+
+    for (k = 0; k < self->naxis; ++k) {
+        cpl_array_set_string(self->cunit, k, self->wcsptr->cunit[k]);
+    }
+
+    return 0;
+}
+
+/*
+ * @internal
+ * @brief
+ *   Update a wcs object.
+ *
+ * @param wcs  The wcs object to update.
+ *
+ * @return
+ *   The function returns the status of the call to wcsset(), or -1 in .
+ *
+ * The function first updates the wcsprm member of the the wcs object @em wcs
+ * and then propagates the updated values to other members of @em where
+ * necessary.
+ *
+ * @note
+ *   If the naxis member of @em wcs differs from the naxis member of the
+ *   underlying wcsprm structure, all affected data members of @em wcs get
+ *   resized accordingly. Actually this should happen only once, on the first
+ *   call to the function when @em is no completely set up.
+ */
+
+inline static int
+_cpl_wcsset(cpl_wcs *wcs)
+{
+
+    struct wcsprm *_wcs = wcs->wcsptr;
+    int status = wcsset(_wcs);
+
+    /*
+     * Update data members of the cpl_wcs object which may have
+     * changed by the call to wcsset()
+     */
+
+    _cpl_wcs_set_cd(wcs);
+
+    _cpl_wcs_set_ctype(wcs);
+    _cpl_wcs_set_cunit(wcs);
+
     return status;
 
 }
+
+
 #ifndef fits_write_hdu
 
 /*-------------------------------------------------------------------------*/
