@@ -1,4 +1,4 @@
-/* $Id: cpl_wcs.h,v 1.14 2012/08/29 14:49:48 llundin Exp $
+/* $Id: cpl_wcs.h,v 1.14 2012-08-29 14:49:48 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/08/29 14:49:48 $
+ * $Date: 2012-08-29 14:49:48 $
  * $Revision: 1.14 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 
@@ -76,6 +76,8 @@ typedef enum cpl_wcs_platesol_outmode cpl_wcs_platesol_outmode;
 
 /* Function prototypes */
 
+CPL_BEGIN_DECLS
+
 cpl_wcs *cpl_wcs_new_from_propertylist(const cpl_propertylist *plist)
     CPL_ATTR_ALLOC;
 void cpl_wcs_delete(cpl_wcs *wcs);
@@ -95,7 +97,11 @@ int cpl_wcs_get_image_naxis(const cpl_wcs *wcs);
 const cpl_array *cpl_wcs_get_image_dims(const cpl_wcs *wcs);
 const cpl_array *cpl_wcs_get_crval(const cpl_wcs *wcs);
 const cpl_array *cpl_wcs_get_crpix(const cpl_wcs *wcs);
+const cpl_array *cpl_wcs_get_ctype(const cpl_wcs *wcs);
+const cpl_array *cpl_wcs_get_cunit(const cpl_wcs *wcs);
 const cpl_matrix *cpl_wcs_get_cd(const cpl_wcs *wcs);
 
+CPL_END_DECLS
+
 #endif /* CPL_WCS_H */
 
