@@ -1352,7 +1352,7 @@ cpl_error_code cpl_wlcalib_fill_line_spectrum_model(cpl_vector * self,
     if (dolog) {
         int i;
         for (i = 0; i < nself; i++) {
-            dself[i] = dself[i] > 0.0 ? log(1.0 + dself[i]) : 0.0;
+            dself[i] = dself[i] > 0.0 ? log1p(dself[i]) : 0.0;
         }
             cpl_tools_add_flops( 2 * nself );
     }
