@@ -1,4 +1,4 @@
-/* $Id: cpl_fft-test.c,v 1.34 2012/05/11 20:55:08 llundin Exp $
+/* $Id: cpl_fft-test.c,v 1.38 2013-10-08 06:11:18 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/05/11 20:55:08 $
- * $Revision: 1.34 $
- * $Name: cpl-6_3_1 $
+ * $Date: 2013-10-08 06:11:18 $
+ * $Revision: 1.38 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -72,6 +72,9 @@ static void cpl_fft_image_test_one(cpl_size, cpl_size, cpl_type);
 static void cpl_fft_imagelist_test_one(cpl_size, cpl_size, cpl_size, cpl_type);
 static
 void cpl_fft_imagelist_test_image(cpl_size, cpl_size, cpl_size, cpl_type);
+
+static void cpl_fft_image_test_correlate(cpl_size, cpl_size, cpl_type);
+
 #endif
 
 /*----------------------------------------------------------------------------*/
@@ -95,39 +98,50 @@ int main(void)
 #pragma omp parallel for private(i)
 #endif
     for (i = 0; i < 2; i++) {
-        const cpl_type type = imtypes[i];
         const cpl_size mz = do_bench ? 10 * IMAGENZ : IMAGENZ;
         cpl_size nz;
 
         /* Collect wisdom */
 #ifdef CPL_FFTWF_INSTALLED
-        if (type == CPL_TYPE_FLOAT) {
-            cpl_fft_image_test_one( 16,  16, type);
-            cpl_fft_image_test_one(  4,  32, type);
-            cpl_fft_image_test_one(  4,   4, type);
-            cpl_fft_image_test_one(  2, 128, type);
-            cpl_fft_image_test_one(128,   2, type);
-            cpl_fft_image_test_one(128,   1, type);
-            cpl_fft_image_test_one(  1, 128, type);
+        if (imtypes[i] == CPL_TYPE_FLOAT) {
+            cpl_fft_image_test_one( 16,  16, imtypes[i]);
+            cpl_fft_image_test_one(  4,  32, imtypes[i]);
+            cpl_fft_image_test_one(  4,   4, imtypes[i]);
+            cpl_fft_image_test_one(  2, 128, imtypes[i]);
+            cpl_fft_image_test_one(128,   2, imtypes[i]);
+            cpl_fft_image_test_one(128,   1, imtypes[i]);
+            cpl_fft_image_test_one(  1, 128, imtypes[i]);
+
+            cpl_fft_image_test_correlate( 16,  16, imtypes[i]);
+            cpl_fft_image_test_correlate( 64, 128, imtypes[i]);
+            cpl_fft_image_test_correlate(128,  64, imtypes[i]);
+            cpl_fft_image_test_correlate(128, 128, imtypes[i]);
 
             if (do_bench) {
-                cpl_fft_image_test_one(256, 256, type);
+                cpl_fft_image_test_one(256, 256, imtypes[i]);
+                cpl_fft_image_test_correlate(512, 512, imtypes[i]);
             }
         }
 #endif
 
 #ifdef CPL_FFTW_INSTALLED
-        if (type == CPL_TYPE_DOUBLE) {
-            cpl_fft_image_test_one( 16,  16, type);
-            cpl_fft_image_test_one( 32,   4, type);
-            cpl_fft_image_test_one(  4,   4, type);
-            cpl_fft_image_test_one(  2, 128, type);
-            cpl_fft_image_test_one(128,   2, type);
-            cpl_fft_image_test_one(128,   1, type);
-            cpl_fft_image_test_one(  1, 128, type);
+        if (imtypes[i] == CPL_TYPE_DOUBLE) {
+            cpl_fft_image_test_one( 16,  16, imtypes[i]);
+            cpl_fft_image_test_one( 32,   4, imtypes[i]);
+            cpl_fft_image_test_one(  4,   4, imtypes[i]);
+            cpl_fft_image_test_one(  2, 128, imtypes[i]);
+            cpl_fft_image_test_one(128,   2, imtypes[i]);
+            cpl_fft_image_test_one(128,   1, imtypes[i]);
+            cpl_fft_image_test_one(  1, 128, imtypes[i]);
+
+            cpl_fft_image_test_correlate( 16,  16, imtypes[i]);
+            cpl_fft_image_test_correlate( 64, 128, imtypes[i]);
+            cpl_fft_image_test_correlate(128,  64, imtypes[i]);
+            cpl_fft_image_test_correlate(128, 128, imtypes[i]);
 
             if (do_bench) {
-                cpl_fft_image_test_one(256, 256, type);
+                cpl_fft_image_test_one(256, 256, imtypes[i]);
+                cpl_fft_image_test_correlate(512, 512, imtypes[i]);
             }
         }
 #endif
@@ -136,33 +150,33 @@ int main(void)
 
         for (nz = 1; nz <= 1 + mz; nz+= mz) {
 #ifdef CPL_FFTWF_INSTALLED
-            if (type == CPL_TYPE_FLOAT) {
-                cpl_fft_imagelist_test_image( 16,  16, nz, type);
-                cpl_fft_imagelist_test_image(  4,  32, nz, type);
-                cpl_fft_imagelist_test_image(  4,   4, nz, type);
-                cpl_fft_imagelist_test_image(  2, 128, nz, type);
-                cpl_fft_imagelist_test_image(128,   2, nz, type);
-                cpl_fft_imagelist_test_image(128,   1, nz, type);
-                cpl_fft_imagelist_test_image(  1, 128, nz, type);
+            if (imtypes[i] == CPL_TYPE_FLOAT) {
+                cpl_fft_imagelist_test_image( 16,  16, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(  4,  32, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(  4,   4, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(  2, 128, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(128,   2, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(128,   1, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(  1, 128, nz, imtypes[i]);
 
                 if (do_bench) {
-                    cpl_fft_imagelist_test_image(256, 256, nz, type);
+                    cpl_fft_imagelist_test_image(256, 256, nz, imtypes[i]);
                 }
             }
 #endif
 
 #ifdef CPL_FFTW_INSTALLED
-            if (type == CPL_TYPE_DOUBLE) {
-                cpl_fft_imagelist_test_image( 16,  16, nz, type);
-                cpl_fft_imagelist_test_image( 32,   4, nz, type);
-                cpl_fft_imagelist_test_image(  4,   4, nz, type);
-                cpl_fft_imagelist_test_image(  2, 128, nz, type);
-                cpl_fft_imagelist_test_image(128,   2, nz, type);
-                cpl_fft_imagelist_test_image(128,   1, nz, type);
-                cpl_fft_imagelist_test_image(  1, 128, nz, type);
+            if (imtypes[i] == CPL_TYPE_DOUBLE) {
+                cpl_fft_imagelist_test_image( 16,  16, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image( 32,   4, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(  4,   4, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(  2, 128, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(128,   2, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(128,   1, nz, imtypes[i]);
+                cpl_fft_imagelist_test_image(  1, 128, nz, imtypes[i]);
 
                 if (do_bench) {
-                    cpl_fft_imagelist_test_image(256, 256, nz, type);
+                    cpl_fft_imagelist_test_image(256, 256, nz, imtypes[i]);
                 }
             }
 #endif
@@ -390,9 +404,9 @@ static void cpl_fft_image_test(void)
 /*----------------------------------------------------------------------------*/
 /**
    @internal
-   @brief  Unit tests of the function
-   @param  nx  Size in x (the number of columns)
-   @param  ny  Size in y (the number of rows)
+   @brief Unit tests of the function
+   @param nx   Size in x (the number of columns)
+   @param ny   Size in y (the number of rows)
    @param type One of CPL_TYPE_DOUBLE or CPL_TYPE_FLOAT
    @see cpl_fft_image()
 **/
@@ -509,10 +523,10 @@ static void cpl_fft_image_test_one(cpl_size nx, cpl_size ny, cpl_type type)
 /*----------------------------------------------------------------------------*/
 /**
    @internal
-   @brief  Unit tests of the function
-   @param  nx  Size in x (the number of columns)
-   @param  ny  Size in y (the number of rows)
-   @param  nz  Size in z (the number of planes/images)
+   @brief Unit tests of the function
+   @param nx   Size in x (the number of columns)
+   @param ny   Size in y (the number of rows)
+   @param nz   Size in z (the number of planes/images)
    @param type One of CPL_TYPE_DOUBLE or CPL_TYPE_FLOAT
    @see cpl_fft_image()
 **/
@@ -695,10 +709,10 @@ static void cpl_fft_imagelist_test_one(cpl_size nx, cpl_size ny, cpl_size nz,
 /*----------------------------------------------------------------------------*/
 /**
    @internal
-   @brief  Benchmark cpl_fft_imagelist() aginst cpl_fft_image()
-   @param  nx  Size in x (the number of columns)
-   @param  ny  Size in y (the number of rows)
-   @param  nz  Size in z (the number of planes/images)
+   @brief Benchmark cpl_fft_imagelist() aginst cpl_fft_image()
+   @param nx   Size in x (the number of columns)
+   @param ny   Size in y (the number of rows)
+   @param nz   Size in z (the number of planes/images)
    @param type One of CPL_TYPE_DOUBLE or CPL_TYPE_FLOAT
    @see cpl_fft_imagelist_test_one() cpl_fft_image_test_one()
 **/
@@ -745,4 +759,91 @@ static void cpl_fft_imagelist_test_image(cpl_size nx, cpl_size ny, cpl_size nz,
     }
 }
 
+
+
+/*----------------------------------------------------------------------------*/
+/**
+   @internal
+   @brief Try to use the FFT for correlation
+   @param nx   Size in x (the number of columns)
+   @param ny   Size in y (the number of rows)
+   @param type One of CPL_TYPE_DOUBLE or CPL_TYPE_FLOAT
+   @see cpl_fft_image_test_one()
+**/
+/*----------------------------------------------------------------------------*/
+static
+void cpl_fft_image_test_correlate(cpl_size nx, cpl_size ny, cpl_type type)
+{
+
+    cpl_image * ia = cpl_image_new(nx, ny, type);
+    cpl_image * ib = cpl_image_new(nx, ny, type);
+    cpl_image * ic = cpl_image_new(nx, ny, type);
+    cpl_image * fa = cpl_image_new(nx, ny, type | CPL_TYPE_COMPLEX);
+    cpl_image * fb = cpl_image_new(nx, ny, type | CPL_TYPE_COMPLEX);
+    cpl_image * fc = cpl_image_new(nx, ny, type | CPL_TYPE_COMPLEX);
+    cpl_imagelist * iab = cpl_imagelist_new();
+    cpl_imagelist * fab = cpl_imagelist_new();
+    cpl_size xmax, ymax;
+    cpl_error_code code;
+
+    code = cpl_imagelist_set(iab, ia, 0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_imagelist_set(iab, ib, 1);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_imagelist_set(fab, fa, 0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_imagelist_set(fab, fb, 1);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_image_fill_gaussian(ia, nx/2.0, ny/2.0, 1.0, 1.0, 1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_image_copy(ib, ia, 1, 1);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_image_shift(ib, nx/4, ny/4);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_fft_imagelist(fab, iab, CPL_FFT_FORWARD);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    /* Auto-correlate */
+    code = cpl_image_conjugate(fc, fa);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_image_multiply(fc, fa);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_fft_image(ic, fc, CPL_FFT_BACKWARD | CPL_FFT_NOSCALE);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_image_get_maxpos(ic, &xmax, &ymax);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    cpl_test_eq(xmax, 1);
+    cpl_test_eq(ymax, 1);
+
+    /* Cross-correlate */
+    code = cpl_image_conjugate(fc, fb);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_image_multiply(fc, fa);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_fft_image(ic, fc, CPL_FFT_BACKWARD | CPL_FFT_NOSCALE);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_image_get_maxpos(ic, &xmax, &ymax);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    cpl_test_eq(xmax, 1 + nx/2 + nx/4);
+    cpl_test_eq(ymax, 1 + ny/2 + ny/4);
+
+    cpl_imagelist_delete(iab);
+    cpl_imagelist_delete(fab);
+    cpl_image_delete(ic);
+    cpl_image_delete(fc);
+}
+
 #endif
