@@ -1,4 +1,4 @@
-/* $Id: cpl_fit-test.c,v 1.47 2012/06/13 14:07:46 llundin Exp $
+/* $Id: cpl_fit-test.c,v 1.48 2013-04-08 15:17:56 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/06/13 14:07:46 $
- * $Revision: 1.47 $
- * $Name: cpl-6_3_1 $
+ * $Date: 2013-04-08 15:17:56 $
+ * $Revision: 1.48 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -118,7 +118,6 @@ int main(void)
     cpl_test_init(PACKAGE_BUGREPORT, CPL_MSG_WARNING);
 
     /* Insert tests below */
-
     cpl_fit_imagelist_polynomial_bpm();
     cpl_fit_image_gaussian_tests(CPL_TYPE_INT);
     cpl_fit_image_gaussian_tests(CPL_TYPE_FLOAT);
@@ -433,18 +432,37 @@ static void cpl_fit_imagelist_polynomial_tests(void)
         error = cpl_imagelist_set(input, image, i);
         cpl_test_eq_error(error, CPL_ERROR_NONE);
 
-        cpl_msg_debug(cpl_func, "Dit and mean of input image no. %"
-                      CPL_SIZE_FORMAT ": %g %g",
-                      i, ditval[i], cpl_image_get_mean(image));
+        cpl_msg_info(cpl_func, "Dit and mean of input image no. %"
+                     CPL_SIZE_FORMAT ": %g %g",
+                     i, ditval[i], cpl_image_get_mean(image));
     }
 
-    fit = cpl_fit_imagelist_polynomial_window_test(vdit, input, 1, 1,
-                                                   IMAGESZFIT, IMAGESZFIT,
-                                                   1, ndits, CPL_FALSE,
-                                                   CPL_TYPE_FLOAT, NULL);
-    cpl_test_error(CPL_ERROR_NONE);
-    cpl_test_nonnull(fit);
-    cpl_imagelist_delete(fit);
+    /* Fit a high-order overdetermined system and a maximum-order,
+       non-overdetermined system */
+
+    for (i = ndits-1; i <= ndits; i++) {
+
+        fit = cpl_fit_imagelist_polynomial_window_test(vdit, input, 1, 1,
+                                                       IMAGESZFIT, IMAGESZFIT,
+                                                       1, i, CPL_FALSE,
+                                                       CPL_TYPE_FLOAT, NULL);
+#if defined SIZEOF_SIZE_T && SIZEOF_SIZE_T == 4
+        if (i == ndits && fit == NULL) {
+            /* FIXME: When fitting a non-overdetermined, maximum-order system
+               on (some) 32-bit machines the rounding errors in the Vandermonde
+               matrix become dominant to the point that the Cholesky
+               decomposition fails.
+            */
+            cpl_test_error(CPL_ERROR_SINGULAR_MATRIX);
+        } else
+#endif
+            {
+                cpl_test_error(CPL_ERROR_NONE);
+                cpl_test_nonnull(fit);
+                cpl_imagelist_delete(fit);
+            }
+
+    }
 
     /* Illegal max-degree */
     fit = cpl_fit_imagelist_polynomial(vdit, input, 1, 0, CPL_FALSE,
