@@ -291,6 +291,7 @@ const double radec[] = {
 static void cpl_wcs_error_test(int);
 static void cpl_wcs_test_propertylist(const cpl_propertylist *);
 static void cpl_wcs_test_one(void);
+static void cpl_wcs_test_5115(void);
 
 int main (void) {
     int i;
@@ -312,6 +313,7 @@ int main (void) {
 
     cpl_test_init(PACKAGE_BUGREPORT,CPL_MSG_WARNING);
 
+    cpl_wcs_test_5115();
     cpl_wcs_test_one();
     cpl_wcs_error_test(1);
 
@@ -884,3 +886,71 @@ static void cpl_wcs_test_one(void)
         cpl_propertylist_delete(pl);
     }
 }
+
+
+
+/*----------------------------------------------------------------------------*/
+/**
+  @internal
+  @brief  Test a given test case
+  @return void
+
+ */
+/*----------------------------------------------------------------------------*/
+static void cpl_wcs_test_5115(void)
+{
+    cpl_propertylist * header = cpl_propertylist_new();
+    cpl_wcs * wcs;
+    cpl_error_code code;
+
+    code = cpl_propertylist_append_int(header, "NAXIS", 3);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_int(header, "NAXIS1", 14);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_int(header, "NAXIS2", 14);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_int(header, "NAXIS3", 10);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_double(header, "CRPIX1", 7.5);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_double(header, "CRPIX2", 7.5);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_double(header, "CRPIX3", 1);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_double(header, "CRVAL1", 6.12595);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_double(header, "CRVAL2", -72.08291);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_double(header, "CRVAL3", 1.43099);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_double(header, "CDELT1", -5.55555e-5);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_double(header, "CDELT2", -5.55555e-5);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_double(header, "CDELT3", 0.0002075);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_string(header, "CTYPE1", "RA---TAN");
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_string(header, "CTYPE2", "DEC--TAN");
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_string(header, "CTYPE3", "WAVE");
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_string(header, "CUNIT1", "deg");
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_string(header, "CUNIT2", "deg");
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_string(header, "CUNIT3", "um");
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_string(header, "ESO PRO FRNAME", "ga");
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+    code = cpl_propertylist_append_int(header, "ESO PRO IFUNR", 1);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    wcs = cpl_wcs_new_from_propertylist(header);
+
+    cpl_test_error(CPL_ERROR_NONE);
+    cpl_test_nonnull(wcs);
+
+    cpl_wcs_delete(wcs);
+    cpl_propertylist_delete(header);
+}
