@@ -1,4 +1,4 @@
-/* $Id: cpl_parameterlist.c,v 1.16 2012/12/13 13:54:18 rpalsa Exp $
+/* $Id: cpl_parameterlist.c,v 1.16 2012-12-13 13:54:18 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/12/13 13:54:18 $
+ * $Date: 2012-12-13 13:54:18 $
  * $Revision: 1.16 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -785,7 +785,7 @@ cpl_parameterlist_find_context_const(const cpl_parameterlist *self,
         }
         else {
 
-            if (_context != NULL) {
+            if (context != NULL && _context != NULL) {
 
                 if (strcmp(_context, context) == 0) {
                     return p;
