@@ -88,8 +88,14 @@ _cx_deque_reserve_at_front(cx_deque *deque, cxsize size)
         deque->front = size;
 
         _members = cx_calloc(_cx_deque_capacity(deque), sizeof(cxptr));
-        memcpy(&_members[deque->front], deque->members,
-               deque->size * sizeof(cxptr));
+
+        if (deque->size > 0) {
+
+            cx_assert(deque->members != NULL);
+            memcpy(&_members[deque->front], deque->members,
+                   deque->size * sizeof(cxptr));
+
+        }
 
         cx_free(deque->members);
         deque->members = _members;
@@ -119,8 +125,14 @@ _cx_deque_reserve_at_back(cx_deque *deque, cxsize size)
         deque->back = size;
 
         _members = cx_calloc(_cx_deque_capacity(deque), sizeof(cxptr));
-        memcpy(&_members[deque->front], &deque->members[deque->front],
-               deque->size * sizeof(cxptr));
+
+        if (deque->size > 0) {
+
+            cx_assert(deque->members != NULL);
+            memcpy(&_members[deque->front], &deque->members[deque->front],
+                   deque->size * sizeof(cxptr));
+
+        }
 
         cx_free(deque->members);
         deque->members = _members;
