@@ -1,4 +1,4 @@
-/* $Id: cxslist.c,v 1.10 2012/03/06 12:33:15 rpalsa Exp $
+/* $Id: cxslist.c,v 1.10 2012-03-06 12:33:15 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/03/06 12:33:15 $
+ * $Date: 2012-03-06 12:33:15 $
  * $Revision: 1.10 $
- * $Name: cpl-6_3_1 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -231,7 +231,7 @@ inline static cx_slist_iterator
 _cx_slist_end(const cx_slist *list)
 {
 
-    list = NULL;
+    (void) list;  /* unused parameter */
     return NULL;
 
 }
@@ -640,6 +640,7 @@ cx_slist_iterator
 cx_slist_next(const cx_slist *list, cx_slist_const_iterator position)
 {
 
+    (void) list;  /* Prevent warnings if cx_assert is disabled. */
     cx_assert(list != NULL);
     cx_assert(_cx_slnode_exists(list, position));
 
@@ -832,6 +833,7 @@ cxsize
 cx_slist_max_size(const cx_slist *list)
 {
 
+    (void) list;  /* Prevent warnings if cx_assert is disabled. */
     cx_assert(list != NULL);
 
     return (cxsize)(-1);
@@ -888,6 +890,7 @@ cx_slist_assign(cx_slist *list, cx_slist_iterator position, cxcptr data)
     cxptr tmp;
 
 
+    (void) list;  /* Prevent warnings if cx_assert is disabled. */
     cx_assert(list != NULL);
     cx_assert(_cx_slnode_exists(list, position));
 
@@ -967,6 +970,7 @@ cxptr
 cx_slist_get(const cx_slist *list, cx_slist_const_iterator position)
 {
 
+    (void) list;  /* Prevent warnings if cx_assert is disabled. */
     cx_assert(list != NULL);
     cx_assert(_cx_slnode_exists(list, position));
 
