@@ -91,6 +91,10 @@ void cx_string_set(cx_string *, const cxchar *);
 /*
  * Modifying operations
  */
+void cx_string_resize(cx_string *, cxsize, cxchar);
+void cx_string_extend(cx_string *, cxsize, cxchar);
+
+void cx_string_replace_character(cx_string *, cxsize, cxsize, cxchar, cxchar);
 
 cx_string *cx_string_upper(cx_string *);
 cx_string *cx_string_lower(cx_string *);
@@ -108,6 +112,8 @@ cx_string *cx_string_insert(cx_string *, cxssize, const cxchar *);
 cx_string *cx_string_erase(cx_string *, cxssize, cxssize);
 cx_string *cx_string_truncate(cx_string *, cxsize);
 
+cx_string *cx_string_substr(const cx_string *, cxsize, cxsize);
+
 /*
  *  Comparison functions
  */
@@ -117,6 +123,13 @@ cxint cx_string_compare(const cx_string *, const cx_string *);
 cxint cx_string_casecmp(const cx_string *, const cx_string *);
 cxint cx_string_ncasecmp(const cx_string *, const cx_string *, cxsize);
 
+/*
+ * Search functions
+ */
+
+cxsize cx_string_find_first_not_of(const cx_string *, const cxchar *);
+cxsize cx_string_find_last_not_of(const cx_string *, const cxchar *);
+
 /*
  * I/O functions
  */
